@@ -22,6 +22,7 @@
 #include <dlfcn.h>
 #include <stdio.h>
 #include <string.h>
+#include <stdlib.h>
 
 #ifdef ANDROID
 #include <android/log.h>
@@ -35,64 +36,87 @@
 // path to application's libraries with trailing slash
 char *libpath = NULL;
 
-char *getlibpath(void){
+char *getlibpath(void)
+{
     char s[AMAXSTR];
     FILE *f;
 
-    if (libpath != NULL) return libpath;
+    if (libpath != NULL) { return libpath; }
 
     f = fopen("/proc/self/maps", "rt");
-    if (!f) return "./";
 
-    while (fgets(s, AMAXSTR - 1, f)){
+    if (!f) { return "./"; }
+
+    while (fgets(s, AMAXSTR - 1, f))
+    {
         char *c;
 
         s[AMAXSTR - 1] = '\0';
         c = strstr(s, ASONAME);
-        if (!c) continue;
+
+        if (!c) { continue; }
 
         // s is like "4a8a5000-4a8a6000 r--p 00018000 1f:01 743        /data/data/cz.nagano.tucnak/lib/libhamlib.so\n"
         *c = '\0';
         c = strchr(s, '/');
-        if (!c) continue;
+
+        if (!c) { continue; }
+
         libpath = malloc(strlen(c) + 1);
         strcpy(libpath, c);
         break;
     }
+
     fclose(f);
     return libpath;
 }
 
-int lt_dlinit(void){
+#ifdef XXREMOVEDXX
+// Not referenced anywhere
+int lt_dlinit(void)
+{
 //    __android_log_print(ANDROID_LOG_DEBUG, PACKAGE_NAME, "lt_dlinit");
     return 0;
 }
+#endif
 
 // not called from hamlib
-int lt_dlexit(void){
+#ifdef XXREMOVEDXX
+// Not referenced anywhere
+int lt_dlexit(void)
+{
 //    __android_log_print(ANDROID_LOG_DEBUG, PACKAGE_NAME, "lt_dlexit");
 
-    if (libpath != NULL){
+    if (libpath != NULL)
+    {
         free(libpath);
         libpath = NULL;
     }
+
     return 0;
 }
+#endif
 
-int lt_dladdsearchdir(const char *search_dir){
+#ifdef XXREMOVEDXX
+int lt_dladdsearchdir(const char *search_dir)
+{
 //    __android_log_print(ANDROID_LOG_DEBUG, PACKAGE_NAME, "lt_dladdsearchdir");
     return 0;
 }
+#endif
 
-lt_dlhandle adlopen(const char *filename){
+lt_dlhandle adlopen(const char *filename)
+{
     char *c;
     lt_dlhandle *ret;
 
 //    __android_log_print(ANDROID_LOG_DEBUG, PACKAGE_NAME, "adlopen('%s')", filename);
     getlibpath();
-    if (libpath == NULL || filename == NULL) return NULL;
 
-    c = malloc(strlen(libpath) + strlen(APREFIX) + strlen(filename) + strlen(ASUFFIX) + 1);
+    if (libpath == NULL || filename == NULL) { return NULL; }
+
+    c = malloc(strlen(libpath) + strlen(APREFIX) + strlen(filename) + strlen(
+                   ASUFFIX) + 1);
     strcpy(c, libpath);
     strcat(c, APREFIX);
     strcat(c, filename);
@@ -104,29 +128,49 @@ lt_dlhandle adlopen(const char *filename){
     return ret;
 }
 
-lt_dlhandle lt_dlopen(const char *filename){
+#ifdef XXREMOVEDXX
+// Not referenced anywhere
+lt_dlhandle lt_dlopen(const char *filename)
+{
 //    __android_log_print(ANDROID_LOG_DEBUG, PACKAGE_NAME, "lt_dlopen(%s)", filename);
     return adlopen(filename);
 }
+#endif
 
-lt_dlhandle lt_dlopenext(const char *filename){
+#ifdef XXREMOVEDXX
+// Not referenced anywhere
+lt_dlhandle lt_dlopenext(const char *filename)
+{
 //    __android_log_print(ANDROID_LOG_DEBUG, PACKAGE_NAME, "lt_dlopenext(%s)", filename);
     return adlopen(filename);
 }
+#endif
 
-int lt_dlclose(lt_dlhandle handle){
+#ifdef XXREMOVEDXX
+// Not referenced anywhere
+int lt_dlclose(lt_dlhandle handle)
+{
 //    __android_log_print(ANDROID_LOG_DEBUG, PACKAGE_NAME, "lt_dlclose");
     return dlclose(handle);
 }
+#endif
 
-void *lt_dlsym(lt_dlhandle handle, const char *name){
+#ifdef XXREMOVEDXX
+// Not referenced anywhere
+void *lt_dlsym(lt_dlhandle handle, const char *name)
+{
     void *ret = dlsym(handle, name);
 //    __android_log_print(ANDROID_LOG_DEBUG, PACKAGE_NAME, "lt_dlsym(%s)=%p", name, ret);
     return ret;
 }
+#endif
 
-const char *lt_dlerror(void){
+#ifdef XXREMOVEDXX
+// Not referenced anywhere
+const char *lt_dlerror(void)
+{
     const char *ret = dlerror();
 //    __android_log_print(ANDROID_LOG_DEBUG, PACKAGE_NAME, "lt_dlerror=%s", ret);
     return ret;
 }
+#endif
