@@ -118,6 +118,9 @@
 #define RIG_MODEL_FT600 RIG_MAKE_MODEL(RIG_YAESU, 39)
 #define RIG_MODEL_FTDX101D RIG_MAKE_MODEL(RIG_YAESU, 40)
 #define RIG_MODEL_FT818 RIG_MAKE_MODEL(RIG_YAESU, 41)
+#define RIG_MODEL_FTDX10 RIG_MAKE_MODEL(RIG_YAESU, 42)
+#define RIG_MODEL_FT897D RIG_MAKE_MODEL(RIG_YAESU, 43)
+#define RIG_MODEL_FTDX101MP RIG_MAKE_MODEL(RIG_YAESU, 44)
 
 
 /*
@@ -173,7 +176,7 @@
 #define RIG_MODEL_PT8000A RIG_MAKE_MODEL(RIG_KENWOOD, 46)
 #define RIG_MODEL_K4 RIG_MAKE_MODEL(RIG_KENWOOD, 47)
 #define RIG_MODEL_POWERSDR RIG_MAKE_MODEL(RIG_KENWOOD, 48)
-
+#define RIG_MODEL_MALACHITE RIG_MAKE_MODEL(RIG_KENWOOD, 49)
 
 /*
  * Icom
@@ -212,7 +215,7 @@
 #define RIG_MODEL_IC775 RIG_MAKE_MODEL(RIG_ICOM, 30)
 #define RIG_MODEL_IC781 RIG_MAKE_MODEL(RIG_ICOM, 31)
 #define RIG_MODEL_IC820 RIG_MAKE_MODEL(RIG_ICOM, 32)
-#define RIG_MODEL_IC821 RIG_MAKE_MODEL(RIG_ICOM, 33)
+//#define RIG_MODEL_IC821 RIG_MAKE_MODEL(RIG_ICOM, 33) // not implemented and can be reused
 #define RIG_MODEL_IC821H RIG_MAKE_MODEL(RIG_ICOM, 34)
 #define RIG_MODEL_IC970 RIG_MAKE_MODEL(RIG_ICOM, 35)
 #define RIG_MODEL_ICR10 RIG_MAKE_MODEL(RIG_ICOM, 36)
@@ -618,6 +621,7 @@
 #define RIG_BARRETT 32
 #define RIG_BACKEND_BARRETT "barrett"
 #define RIG_MODEL_BARRETT_2050 RIG_MAKE_MODEL(RIG_BARRETT, 1)
+#define RIG_MODEL_BARRETT_950 RIG_MAKE_MODEL(RIG_BARRETT, 2)
 
 /*
  * Elad
