@@ -117,7 +117,7 @@ struct trxmanager_priv_data
 struct rig_caps trxmanager_caps =
 {
     RIG_MODEL(RIG_MODEL_TRXMANAGER_RIG),
-    .model_name = "5.7.630+",
+    .model_name = "TRXManager 5.7.630+",
     .mfg_name = "TRXManager",
     .version = BACKEND_VER ".0",
     .copyright = "LGPL",
@@ -1157,7 +1157,7 @@ static int trxmanager_set_split_freq_mode(RIG *rig, vfo_t vfo, freq_t freq,
 
     rig_debug(RIG_DEBUG_TRACE, "%s\n", __func__);
 
-    if (vfo != RIG_VFO_CURR && vfo != RIG_VFO_TX)
+    if (vfo != RIG_VFO_CURR && vfo != RIG_VFO_TX && vfo != RIG_VFO_B)
     {
         return -RIG_ENTARGET;
     }
