@@ -23,11 +23,9 @@
 #include "config.h"
 #endif
 
-#include <stdlib.h>
 #include <string.h>  /* String function definitions */
 
 #include <hamlib/rig.h>
-#include "token.h"
 #include "idx_builtin.h"
 
 #include "icom.h"
@@ -36,7 +34,6 @@
 #include "misc.h"
 #include "bandplan.h"
 
-
 #define IC756_ALL_RX_MODES (RIG_MODE_AM|RIG_MODE_CW|RIG_MODE_CWR|RIG_MODE_SSB|RIG_MODE_RTTY|RIG_MODE_RTTYR|RIG_MODE_FM)
 #define IC756_1HZ_TS_MODES IC756_ALL_RX_MODES
 
@@ -130,7 +127,7 @@ static const struct icom_priv_caps ic756_priv_caps =
     0,       /* 731 mode */
     0,       /* no XCHG */
     ic756_ts_sc_list,
-    .antack_len = 2,
+    .antack_len = 3,
     .ant_count = 2,
     .r2i_mode = r2i_mode,
     .agc_levels_present = 1,
@@ -182,6 +179,8 @@ const struct rig_caps ic756_caps =
     .max_rit =  Hz(9999),
     .max_xit =  Hz(0),
     .max_ifshift =  Hz(0),
+    .agc_level_count = 3,
+    .agc_levels = { RIG_AGC_FAST, RIG_AGC_MEDIUM, RIG_AGC_SLOW },
     .targetable_vfo =  0,
     .vfo_ops =  IC756_VFO_OPS,
     .scan_ops =  IC756_SCAN_OPS,
@@ -292,7 +291,7 @@ static const struct icom_priv_caps ic756pro_priv_caps =
     0,        /* 731 mode */
     0,    /* no XCHG */
     ic756pro_ts_sc_list,
-    .antack_len = 2,
+    .antack_len = 3,
     .ant_count = 2,
     .agc_levels_present = 1,
     .agc_levels = {
@@ -344,6 +343,8 @@ const struct rig_caps ic756pro_caps =
     .max_rit =  Hz(9999),
     .max_xit =  Hz(0),
     .max_ifshift =  Hz(0),
+    .agc_level_count = 3,
+    .agc_levels = { RIG_AGC_FAST, RIG_AGC_MEDIUM, RIG_AGC_SLOW },
     .targetable_vfo =  0,
     .vfo_ops =  IC756_VFO_OPS,
     .scan_ops =  IC756_SCAN_OPS,
@@ -460,7 +461,7 @@ static const struct icom_priv_caps ic756pro2_priv_caps =
     0,       /* 731 mode */
     0,       /* no XCHG */
     ic756pro_ts_sc_list,
-    .antack_len = 2,
+    .antack_len = 3,
     .ant_count = 2,
     .agc_levels_present = 1,
     .agc_levels = {
@@ -581,6 +582,8 @@ const struct rig_caps ic756pro2_caps =
     .max_rit =  Hz(9999),
     .max_xit =  Hz(9999),
     .max_ifshift =  Hz(0),
+    .agc_level_count = 3,
+    .agc_levels = { RIG_AGC_FAST, RIG_AGC_MEDIUM, RIG_AGC_SLOW },
     .targetable_vfo =  0,
     .vfo_ops =  IC756_VFO_OPS,
     .scan_ops =  IC756_SCAN_OPS,
@@ -887,7 +890,7 @@ static const struct icom_priv_caps ic756pro3_priv_caps =
     0,       /* 731 mode */
     0,       /* no XCHG */
     ic756pro_ts_sc_list,
-    .antack_len = 2,
+    .antack_len = 3,
     .ant_count = 2,
     .agc_levels_present = 1,
     .agc_levels = {
@@ -943,13 +946,24 @@ static const struct icom_priv_caps ic756pro3_priv_caps =
          { 120, 1.0f } \
     } }
 
-#define IC756PROIII_RFPOWER_METER_CAL { 3, \
+#define IC756PROIII_RFPOWER_METER_CAL { 13, \
     { \
          { 0, 0.0f }, \
-         { 143, 0.5f }, \
-         { 213, 1.0f } \
+         { 21, 5.0f }, \
+         { 43, 10.0f }, \
+         { 65, 15.0f }, \
+         { 83, 20.0f }, \
+         { 95, 25.0f }, \
+         { 105, 30.0f }, \
+         { 114, 35.0f }, \
+         { 124, 40.0f }, \
+         { 143, 50.0f }, \
+         { 183, 75.0f }, \
+         { 213, 100.0f }, \
+         { 255, 120.0f } \
     } }
 
+
 #define IC756PROIII_COMP_METER_CAL { 3, \
     { \
          { 0, 0.0f }, \
@@ -962,7 +976,7 @@ const struct rig_caps ic756pro3_caps =
     RIG_MODEL(RIG_MODEL_IC756PROIII),
     .model_name = "IC-756PROIII",
     .mfg_name =  "Icom",
-    .version =  BACKEND_VER ".0",
+    .version =  BACKEND_VER ".1",
     .copyright =  "LGPL",
     .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -1000,6 +1014,8 @@ const struct rig_caps ic756pro3_caps =
     .max_rit =  Hz(9999),
     .max_xit =  Hz(9999),
     .max_ifshift =  Hz(0),
+    .agc_level_count = 3,
+    .agc_levels = { RIG_AGC_FAST, RIG_AGC_MEDIUM, RIG_AGC_SLOW },
     .targetable_vfo =  0,
     .vfo_ops =  IC756_VFO_OPS | RIG_OP_TUNE,
     .scan_ops =  IC756_SCAN_OPS,
