@@ -35,6 +35,7 @@
 #include "elecraft.h"
 #include "token.h"
 #include "cal.h"
+#include "iofunc.h"
 
 #define K3_MODES (RIG_MODE_CW|RIG_MODE_CWR|RIG_MODE_SSB|\
     RIG_MODE_RTTY|RIG_MODE_RTTYR|RIG_MODE_FM|RIG_MODE_AM|RIG_MODE_PKTUSB|\
@@ -142,6 +143,7 @@ static struct kenwood_priv_caps k3_priv_caps  =
 /* K3 specific function declarations */
 int k3_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width);
 int k3_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width);
+int k3_get_vfo(RIG *rig, vfo_t *vfo);
 int k3_set_vfo(RIG *rig, vfo_t vfo);
 int k3_set_ext_level(RIG *rig, vfo_t vfo, token_t token, value_t val);
 int k3_get_ext_level(RIG *rig, vfo_t vfo, token_t token, value_t *val);
@@ -181,7 +183,7 @@ const struct rig_caps k3_caps =
     RIG_MODEL(RIG_MODEL_K3),
     .model_name =       "K3",
     .mfg_name =     "Elecraft",
-    .version =      BACKEND_VER ".2",
+    .version =      BACKEND_VER ".16",
     .copyright =        "LGPL",
     .status =       RIG_STATUS_STABLE,
     .rig_type =     RIG_TYPE_TRANSCEIVER,
@@ -218,7 +220,7 @@ const struct rig_caps k3_caps =
     .max_xit =      Hz(9990),
     .max_ifshift =      Hz(0),
     .vfo_ops =      K3_VFO_OP,
-    .targetable_vfo =   RIG_TARGETABLE_FREQ,
+    .targetable_vfo =   RIG_TARGETABLE_FREQ | RIG_TARGETABLE_MODE,
     .transceive =       RIG_TRN_RIG,
     .bank_qty =     0,
     .chan_desc_sz =     0,
@@ -295,7 +297,7 @@ const struct rig_caps k3_caps =
     .set_mode =     k3_set_mode,
     .get_mode =     k3_get_mode,
     .set_vfo =      k3_set_vfo,
-    .get_vfo =      kenwood_get_vfo_if,
+    .get_vfo =      k3_get_vfo,
     .set_split_mode =   k3_set_split_mode,
     .get_split_mode =   k3_get_split_mode,
     .set_split_vfo =    kenwood_set_split_vfo,
@@ -332,7 +334,7 @@ const struct rig_caps k3s_caps =
     RIG_MODEL(RIG_MODEL_K3S),
     .model_name =       "K3S",
     .mfg_name =     "Elecraft",
-    .version =      BACKEND_VER ".2",
+    .version =      BACKEND_VER ".14",
     .copyright =        "LGPL",
     .status =       RIG_STATUS_STABLE,
     .rig_type =     RIG_TYPE_TRANSCEIVER,
@@ -368,7 +370,7 @@ const struct rig_caps k3s_caps =
     .max_xit =      Hz(9990),
     .max_ifshift =      Hz(0),
     .vfo_ops =      K3_VFO_OP,
-    .targetable_vfo =   RIG_TARGETABLE_FREQ,
+    .targetable_vfo =   RIG_TARGETABLE_FREQ | RIG_TARGETABLE_MODE,
     .transceive =       RIG_TRN_RIG,
     .bank_qty =     0,
     .chan_desc_sz =     0,
@@ -445,7 +447,7 @@ const struct rig_caps k3s_caps =
     .set_mode =     k3_set_mode,
     .get_mode =     k3_get_mode,
     .set_vfo =      k3_set_vfo,
-    .get_vfo =      kenwood_get_vfo_if,
+    .get_vfo =      k3_get_vfo,
     .set_split_mode =   k3_set_split_mode,
     .get_split_mode =   k3_get_split_mode,
     .set_split_vfo =    kenwood_set_split_vfo,
@@ -482,9 +484,9 @@ const struct rig_caps k4_caps =
     RIG_MODEL(RIG_MODEL_K4),
     .model_name =       "K4",
     .mfg_name =     "Elecraft",
-    .version =      BACKEND_VER ".2",
+    .version =      BACKEND_VER ".14",
     .copyright =        "LGPL",
-    .status =       RIG_STATUS_ALPHA,
+    .status =       RIG_STATUS_STABLE,
     .rig_type =     RIG_TYPE_TRANSCEIVER,
     .ptt_type =     RIG_PTT_RIG,
     .dcd_type =     RIG_DCD_RIG,
@@ -518,7 +520,7 @@ const struct rig_caps k4_caps =
     .max_xit =      Hz(9990),
     .max_ifshift =      Hz(0),
     .vfo_ops =      K3_VFO_OP,
-    .targetable_vfo =   RIG_TARGETABLE_FREQ,
+    .targetable_vfo =   RIG_TARGETABLE_FREQ | RIG_TARGETABLE_MODE,
     .transceive =       RIG_TRN_RIG,
     .bank_qty =     0,
     .chan_desc_sz =     0,
@@ -595,7 +597,7 @@ const struct rig_caps k4_caps =
     .set_mode =     k3_set_mode,
     .get_mode =     k3_get_mode,
     .set_vfo =      k3_set_vfo,
-    .get_vfo =      kenwood_get_vfo_if,
+    .get_vfo =      k3_get_vfo,
     .set_split_mode =   k3_set_split_mode,
     .get_split_mode =   k3_get_split_mode,
     .set_split_vfo =    kenwood_set_split_vfo,
@@ -631,9 +633,9 @@ const struct rig_caps kx3_caps =
     RIG_MODEL(RIG_MODEL_KX3),
     .model_name =       "KX3",
     .mfg_name =     "Elecraft",
-    .version =      BACKEND_VER ".2",
+    .version =      BACKEND_VER ".14",
     .copyright =        "LGPL",
-    .status =       RIG_STATUS_BETA,
+    .status =       RIG_STATUS_STABLE,
     .rig_type =     RIG_TYPE_TRANSCEIVER,
     .ptt_type =     RIG_PTT_RIG,
     .dcd_type =     RIG_DCD_RIG,
@@ -667,7 +669,7 @@ const struct rig_caps kx3_caps =
     .max_xit =      Hz(9990),
     .max_ifshift =      Hz(0),
     .vfo_ops =      K3_VFO_OP,
-    .targetable_vfo =   RIG_TARGETABLE_FREQ,
+    .targetable_vfo =   RIG_TARGETABLE_FREQ | RIG_TARGETABLE_MODE,
     .transceive =       RIG_TRN_RIG,
     .bank_qty =     0,
     .chan_desc_sz =     0,
@@ -744,7 +746,7 @@ const struct rig_caps kx3_caps =
     .set_mode =     k3_set_mode,
     .get_mode =     k3_get_mode,
     .set_vfo =      k3_set_vfo,
-    .get_vfo =      kenwood_get_vfo_if,
+    .get_vfo =      k3_get_vfo,
     .set_split_mode =   k3_set_split_mode,
     .get_split_mode =   k3_get_split_mode,
     .set_split_vfo =    kenwood_set_split_vfo,
@@ -780,9 +782,9 @@ const struct rig_caps kx2_caps =
     RIG_MODEL(RIG_MODEL_KX2),
     .model_name =       "KX2",
     .mfg_name =     "Elecraft",
-    .version =      BACKEND_VER ".2",
+    .version =      BACKEND_VER ".14",
     .copyright =        "LGPL",
-    .status =       RIG_STATUS_BETA,
+    .status =       RIG_STATUS_STABLE,
     .rig_type =     RIG_TYPE_TRANSCEIVER,
     .ptt_type =     RIG_PTT_RIG,
     .dcd_type =     RIG_DCD_RIG,
@@ -816,7 +818,7 @@ const struct rig_caps kx2_caps =
     .max_xit =      Hz(9990),
     .max_ifshift =      Hz(0),
     .vfo_ops =      K3_VFO_OP,
-    .targetable_vfo =   RIG_TARGETABLE_FREQ,
+    .targetable_vfo =   RIG_TARGETABLE_FREQ | RIG_TARGETABLE_MODE,
     .transceive =       RIG_TRN_RIG,
     .bank_qty =     0,
     .chan_desc_sz =     0,
@@ -893,7 +895,7 @@ const struct rig_caps kx2_caps =
     .set_mode =     k3_set_mode,
     .get_mode =     k3_get_mode,
     .set_vfo =      k3_set_vfo,
-    .get_vfo =      kenwood_get_vfo_if,
+    .get_vfo =      k3_get_vfo,
     .set_split_mode =   k3_set_split_mode,
     .get_split_mode =   k3_get_split_mode,
     .set_split_vfo =    kenwood_set_split_vfo,
@@ -949,6 +951,11 @@ int k3_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
         return -RIG_EINVAL;
     }
 
+    if (vfo == RIG_VFO_CURR)
+    {
+        vfo = rig->state.current_vfo;
+    }
+
     err = kenwood_get_mode(rig, vfo, &temp_m, &temp_w);
 
     if (err != RIG_OK)
@@ -998,11 +1005,11 @@ int k3_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
         {
         case K3_MODE_DATA_A:
         case K3_MODE_PSK_D:
-            *mode = RIG_MODE_PKTLSB;
+            *mode = RIG_MODE_PKTUSB;
             break;
 
         case K3_MODE_AFSK_A:
-            *mode = RIG_MODE_PKTUSB;
+            *mode = RIG_MODE_PKTLSB;
             break;
 
         case K3_MODE_FSK_D:
@@ -1019,7 +1026,14 @@ int k3_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
     /* The K3 is not limited to specific filter widths so we can query
      * the actual bandwidth using the BW command
      */
-    err = kenwood_safe_transaction(rig, "BW", buf, KENWOOD_MAX_BUF_LEN, 6);
+    if (vfo == RIG_VFO_B)
+    {
+        err = kenwood_safe_transaction(rig, "BW$", buf, KENWOOD_MAX_BUF_LEN, 7);
+    }
+    else
+    {
+        err = kenwood_safe_transaction(rig, "BW", buf, KENWOOD_MAX_BUF_LEN, 6);
+    }
 
     if (err != RIG_OK)
     {
@@ -1027,7 +1041,14 @@ int k3_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
         return err;
     }
 
-    *width = atoi(&buf[2]) * 10;
+    if (vfo == RIG_VFO_B)
+    {
+        *width = atoi(&buf[3]) * 10;
+    }
+    else
+    {
+        *width = atoi(&buf[2]) * 10;
+    }
 
     return RIG_OK;
 }
@@ -1041,15 +1062,24 @@ int k3_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
  * The K3 supports AFSK & FSK sub-modes and for the D versions it also
  * has an internal RTTY and PSK31 decoder. The decoder sub-modes are
  * reported as FSK (RTTY) and the AFSK sub-modes are reported as
- * PKT(USB & LSB). LSB modes are assumed to be RTTY and USB modes are
- * assumed to be PKT(PSK, WS modes etc.).
+ * PKT(USB & LSB). The Submode determines if MD6 starts off in USB
+ * or LSB. To get the reverse of that, you send MD9 and the the submode.
+ * On KX3 it's
+ *
+ * DT0 defaults MD6 to USB
+ * DT1 defaults MD6 to LSB
+ * DT2 defaults MD6 to LSB
+ * DT3 defaults MD6 to USB
+ *
+ * So to inverse that DT0 for LSB, you'd send MD9 then DT0.
  *
  * For mode set the data sub-modes are set as follows:
  *
- * RTTY -> FSK D normal (LSB) VFO shows MARK QRG
- * RTTYR -> FSK D reversed (USB) VFO shows MARK QRG
- * PKTUSB -> DATA A normal (USB) VFO shows suppressed carrier QRG
- * PKTLSB -> AFSK A normal (LSB) optimised for RTTY VFO shows MARK QRG
+ * PKTUSB = sets the rig to DATA mode submode Data A (DT0)
+ * PKTLSB = sets the rig to DATA REV mode submode Data A (DT0)
+ * RTTY = sets the rig to AFSK A 45 bps rtty (DT1)
+ * RTTYR = sets the rig to FSK D 45 bps rtty (DT2)
+ * PSK = sets the rig to PSK D (DT3)
 
  * Not all data sub-mode combinations are possible but the above
  * mapping seems most likely to cover the user requirements.
@@ -1059,41 +1089,104 @@ int k3_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
     int err;
     char cmd_m[4];
+    char buf[KENWOOD_MAX_BUF_LEN];
+    struct kenwood_priv_caps *caps = kenwood_caps(rig);
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
+    if (vfo == RIG_VFO_CURR)
+    {
+        vfo = rig->state.current_vfo;
+    }
+
+    rmode_t tmode;
+    pbwidth_t twidth;
+    err = k3_get_mode(rig, vfo, &tmode, &twidth);
+
+    if (err == RIG_OK && tmode == mode && width == RIG_PASSBAND_NOCHANGE)
+    {
+        rig_debug(RIG_DEBUG_TRACE, "%s(%d): mode/width no change, skipping\n", __FILE__,
+                  __LINE__);
+        return RIG_OK;
+    }
+    else
+    {
+        rig_debug(RIG_DEBUG_TRACE,
+                  "%s(%d): changing mode=%s, oldmode=%s, width=%ld, oldwidth=%ld\n", __FILE__,
+                  __LINE__, rig_strrmode(tmode), rig_strrmode(mode), twidth, width);
+    }
+
     switch (mode)
     {
     case RIG_MODE_PKTLSB:
-        mode = RIG_MODE_RTTY;
+        mode = RIG_MODE_RTTYR; // in "DT0" Subband RIG_MODE_RTTYR = USB and RIG_MODE_RTTY = LSB
         snprintf(cmd_m, sizeof(cmd_m),
-                 "DT1"); /* AFSK A mode - AFSK on LSB optimised for RTTY, VFO dial is MARK */
+                 "DT0"); /* DATA A mode - DATA (REV) on LSB optimized for HF Packet, VFO dial is suppressed carrier QRG */
         break;
 
     case RIG_MODE_PKTUSB:
-        mode = RIG_MODE_RTTY;
+        mode = RIG_MODE_RTTY; // in "DT0" Subband RIG_MODE_RTTYR = USB and RIG_MODE_RTTY = LSB
         snprintf(cmd_m, sizeof(cmd_m),
-                 "DT0"); /* DATA A mode - AFSK on USB general, VFO dial is suppressed carrier QRG */
+                 "DT0"); /* DATA A mode - DATA on USB general, VFO dial is suppressed carrier QRG */
         break;
 
     case RIG_MODE_RTTY:
-    case RIG_MODE_RTTYR:
+        mode = RIG_MODE_RTTY; // in "DT1" Subband RIG_MODE_RTTY = LSB and RIG_MODE_RTTYR = USB
         snprintf(cmd_m, sizeof(cmd_m),
-                 "DT2"); /* FSK D mode - direct FSK keying, LSB is "normal", VFO dial is MARK */
+                 "DT2"); /* FSK D mode - direct FSK on LSB optimized for RTTY, VFO dial is MARK */
+        break;
+
+    case RIG_MODE_RTTYR:
+        mode = RIG_MODE_RTTYR; // in "DT2" Subband RIG_MODE_RTTY = LSB and RIG_MODE_RTTYR = USB
+        snprintf(cmd_m, sizeof(cmd_m),
+                 "DT1"); /* FSK D mode - direct FSK keying, LSB is "normal", VFO dial is MARK */
+        break;
+
+    case RIG_MODE_PSK:
+        mode = RIG_MODE_PSK; // in "DT3" subband RIG_MODE_PSK = USB # kenwood.c mode but may need kenwwod.c mode table review.
+        snprintf(cmd_m, sizeof(cmd_m),
+                 "DT3"); /* PSK D Mode - direct PSK keying, USB is "normal", VFO dial is MARK */
         break;
 
     default:
         break;
     }
 
-    /* kenwood_set_mode() ignores width value for K2/K3/TS-570 */
-    err = kenwood_set_mode(rig, vfo, mode, width);
+    int kmode;
+    int c;
+    kmode = rmode2kenwood(mode, caps->mode_table);
 
-    if (err != RIG_OK)
+    if (kmode < 0)
     {
-        return err;
+        rig_debug(RIG_DEBUG_WARN, "%s: unsupported mode '%s'\n",
+                  __func__, rig_strrmode(mode));
+        RETURNFUNC(-RIG_EINVAL);
     }
 
+    if (kmode <= 9)
+    {
+        c = '0' + kmode;
+    }
+    else
+    {
+        c = 'A' + kmode - 10;
+    }
+
+    rig_debug(RIG_DEBUG_VERBOSE, "%s: kmode=%d, cmode=%c\n", __func__, kmode, c)
+
+    if (vfo == RIG_VFO_B)
+    {
+        snprintf(buf, sizeof(buf), "MD$%c", c);
+    }
+    else
+    {
+        snprintf(buf, sizeof(buf), "MD%c", c);
+    }
+
+    err = kenwood_transaction(rig, buf, NULL, 0);
+
+    if (err != RIG_OK) { RETURNFUNC(err); }
+
     if (width != RIG_PASSBAND_NOCHANGE)
     {
         char cmd_s[64];
@@ -1108,8 +1201,8 @@ int k3_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
          */
 
         /* passband widths vary by mode so gather lower and upper limits */
-        pbwidth_t pb_nar = rig_passband_narrow(rig, mode);
-        pbwidth_t pb_wid = rig_passband_wide(rig, mode);
+        //pbwidth_t pb_nar = rig_passband_narrow(rig, mode);
+        //pbwidth_t pb_wid = rig_passband_wide(rig, mode);
 
         if (width < 0)
         {
@@ -1120,6 +1213,8 @@ int k3_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
         {
             width = rig_passband_normal(rig, mode);
         }
+
+#if 0
         else if (width < pb_nar)
         {
             width = pb_nar;
@@ -1129,7 +1224,30 @@ int k3_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
             width = pb_wid;
         }
 
-        snprintf(cmd_s, sizeof(cmd_s), "BW%04ld", width / 10);
+#endif
+        // width is 50Hz rounded down
+        struct kenwood_priv_data *priv = rig->state.priv;
+
+        if (priv->is_k4d || priv->is_k4hd)
+        {
+            width += 9;  // rounds to 10Hz
+        }
+        else
+        {
+            width += 49;
+        }
+
+        if (width > 99999) { width = 99999; }
+
+        if (vfo == RIG_VFO_B)
+        {
+            snprintf(cmd_s, sizeof(cmd_s), "BW$%04ld", width / 10);
+        }
+        else
+        {
+            snprintf(cmd_s, sizeof(cmd_s), "BW%04ld", width / 10);
+        }
+
         err = kenwood_transaction(rig, cmd_s, NULL, 0);
 
         if (err != RIG_OK)
@@ -1155,38 +1273,28 @@ int k3_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     return RIG_OK;
 }
 
-
-/* The K3 changes "VFOs" by swapping the contents of
- * the upper display with the lower display.  This function
- * accomplishes this by sending the emulation command, SWT11;
- * to the K3 to emulate a tap of the A/B button.
+/* Elecraft rigs don't really know about swappings vfos.
+ * We just emulate them so rigctl can work correctly.
  */
 
 int k3_set_vfo(RIG *rig, vfo_t vfo)
 {
-    int err;
+    ENTERFUNC;
 
-    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+    // we emulate vfo selection for Elecraft
+    rig->state.current_vfo = vfo;
 
-    switch (vfo)
-    {
-    case RIG_VFO_B:
-        err = kenwood_transaction(rig, "SWT11", NULL, 0);
-
-        if (err != RIG_OK)
-        {
-            return err;
-        }
-
-        break;
-
-    default:
-        break;
-    }
-
-    return RIG_OK;
+    RETURNFUNC(RIG_OK);
 }
 
+int k3_get_vfo(RIG *rig, vfo_t *vfo)
+{
+    ENTERFUNC;
+
+    *vfo = rig->state.current_vfo;
+
+    RETURNFUNC(RIG_OK);
+}
 
 /* Support the RC command for clearing RIT/XIT,
  *
@@ -1364,47 +1472,99 @@ int k3_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode, pbwidth_t tx_width)
     char buf[32];
     char kmode;
     int err;
-    char cmd_m[4];
+    char cmd_m[16];
+    struct kenwood_priv_data *priv = rig->state.priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
     switch (tx_mode)
     {
     case RIG_MODE_PKTLSB:
-        tx_mode = RIG_MODE_RTTY;
+        tx_mode = RIG_MODE_RTTYR; // "DT0" RIG_MODE_RTTY = LSB
         snprintf(cmd_m, sizeof(cmd_m),
-                 "DT1"); /* AFSK A mode - AFSK on LSB optimised for RTTY, VFO dial is MARK */
+                 "DT0;"); /* DATA A mode - DATA-R LSB, suppressed carrier */
+
+        if (priv->is_k4d || priv->is_k4hd)
+        {
+            strcat(cmd_m, "DT$0;");
+        }
+
         break;
 
     case RIG_MODE_PKTUSB:
-        tx_mode = RIG_MODE_RTTY;
+        tx_mode = RIG_MODE_RTTY; // "DT0" RIG_MODE_RTTYR = USB
         snprintf(cmd_m, sizeof(cmd_m),
-                 "DT0"); /* DATA A mode - AFSK on USB general, VFO dial is suppressed carrier QRG */
+                 "DT0;"); /* DATA A mode - DATA on USB, suppressed carrier */
+
+        if (priv->is_k4d || priv->is_k4hd)
+        {
+            strcat(cmd_m, "DT$0;");
+        }
+
         break;
 
     case RIG_MODE_RTTY:
-    case RIG_MODE_RTTYR:
+        tx_mode = RIG_MODE_RTTY; // DT1" RIG_MODE_RTTY = LSB and RIG_MODE_RTTYR = USB
         snprintf(cmd_m, sizeof(cmd_m),
-                 "DT2"); /* FSK D mode - direct FSK keying, LSB is "normal", VFO dial is MARK */
+                 "DT2;"); /* FSK D mode - direct FSK on LSB optimized for RTTY, VFO dial is MARK */
+
+        if (priv->is_k4d || priv->is_k4hd)
+        {
+            strcat(cmd_m, "DT$2;");
+        }
+
+        break;
+
+    case RIG_MODE_RTTYR:
+        tx_mode = RIG_MODE_RTTYR; // "DT2" RIG_MODE_RTTY = USB and RIG_MODE_RTTYR = USB
+        snprintf(cmd_m, sizeof(cmd_m),
+                 "DT1;"); /* FSK D mode - direct FSK on USB optimized for RTTY, VFO dial is MARK */
+
+        if (priv->is_k4d || priv->is_k4hd)
+        {
+            strcat(cmd_m, "DT$1;");
+        }
+
+        break;
+
+    case RIG_MODE_PSK:
+        tx_mode = RIG_MODE_PSK;
+        snprintf(cmd_m, sizeof(cmd_m),
+                 "DT3;FT1;"); /* PSK D Mode - direct PSK keying, USB is "normal", VFO dial is MARK */
+
+        if (priv->is_k4d || priv->is_k4hd)
+        {
+            strcat(cmd_m, "DT$3;");
+        }
+
         break;
 
     default:
         break;
     }
 
-#if 0
+// Enabling this clause for just the K4 for now
+#if 1
 
-    /* Set data sub-mode.  K3 needs to be in a DATA mode before setting
-     * the sub-mode or switching to VFOB so we do this before the MD$ command.
-     */
-    if (tx_mode == RIG_MODE_PKTLSB || tx_mode == RIG_MODE_PKTUSB
-            || tx_mode == RIG_MODE_RTTY || tx_mode == RIG_MODE_RTTYR)
+    if (priv->is_k4d || priv->is_k4hd)
     {
-        err = kenwood_transaction(rig, cmd_m, NULL, 0);
+        // split can get turned off when modes are changing
+        // so if the rig did this independtly of us we turn it back on
+        // even if the rig changes the split status should be the last thing we did
+        if (priv->split) { strcat(cmd_m, "FT1;"); }
 
-        if (err != RIG_OK)
+        /* Set data sub-mode.  K3 needs to be in a DATA mode before setting
+         * the sub-mode or switching to VFOB so we do this before the MD$ command.
+         */
+        if (tx_mode == RIG_MODE_PKTLSB || tx_mode == RIG_MODE_PKTUSB
+                || tx_mode == RIG_MODE_RTTY || tx_mode == RIG_MODE_RTTYR)
         {
-            return err;
+            err = kenwood_transaction(rig, cmd_m, NULL, 0);
+
+            if (err != RIG_OK)
+            {
+                return err;
+            }
         }
     }
 
@@ -1441,8 +1601,8 @@ int k3_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode, pbwidth_t tx_width)
          */
 
         /* passband widths vary by mode so gather lower and upper limits */
-        pbwidth_t pb_nar = rig_passband_narrow(rig, tx_mode);
-        pbwidth_t pb_wid = rig_passband_wide(rig, tx_mode);
+        //pbwidth_t pb_nar = rig_passband_narrow(rig, tx_mode);
+        //pbwidth_t pb_wid = rig_passband_wide(rig, tx_mode);
 
         if (tx_width < 0)
         {
@@ -1453,6 +1613,8 @@ int k3_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode, pbwidth_t tx_width)
         {
             tx_width = rig_passband_normal(rig, tx_mode);
         }
+
+#if 0
         else if (tx_width < pb_nar)
         {
             tx_width = pb_nar;
@@ -1462,6 +1624,8 @@ int k3_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode, pbwidth_t tx_width)
             tx_width = pb_wid;
         }
 
+#endif
+
         snprintf(cmd_s, sizeof(cmd_s), "BW$%04ld", tx_width / 10);
         err = kenwood_transaction(rig, cmd_s, NULL, 0);
 
@@ -1584,7 +1748,7 @@ static int k3_get_maxpower(RIG *rig)
 {
     int retval;
     int maxpower = 12; // K3 default power level
-    char levelbuf[16];
+    char levelbuf[KENWOOD_MAX_BUF_LEN];
     struct kenwood_priv_data *priv = rig->state.priv;
 
     // default range is 0-12 if there is no KPA3 installed
@@ -1689,7 +1853,7 @@ int k3_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
             int i;
             int foundit = 0;
 
-            for (i = 0; i < MAXDBLSTSIZ && rig->state.attenuator[i]; i++)
+            for (i = 0; i < HAMLIB_MAXDBLSTSIZ && rig->state.attenuator[i]; i++)
             {
                 if (val.i == rig->state.attenuator[i])
                 {
@@ -1924,7 +2088,7 @@ int k3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         {
             int i;
 
-            for (i = 0; i < lvl && i < MAXDBLSTSIZ; i++)
+            for (i = 0; i < lvl && i < HAMLIB_MAXDBLSTSIZ; i++)
             {
                 if (rig->state.attenuator[i] == 0)
                 {
@@ -2129,6 +2293,24 @@ int kx3_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         val->f = pwr;
         return retval;
     }
+
+    case RIG_LEVEL_RFPOWER_METER_WATTS:
+    {
+        struct kenwood_priv_data *priv = rig->state.priv;
+        char levelbuf[KENWOOD_MAX_BUF_LEN];
+        int pwr;
+
+        retval = kenwood_safe_transaction(rig, "PO", levelbuf, sizeof(levelbuf), 5);
+
+        if (retval != RIG_OK)
+        {
+            return retval;
+        }
+
+        sscanf(levelbuf + 2, "%d", &pwr);
+        val->f = priv->has_kpa100 ? pwr : pwr / 10.0;
+        return retval;
+    }
     }
 
     return k3_get_level(rig, vfo, level, val);
