@@ -103,7 +103,7 @@ const struct rig_caps pihpsdr_caps =
     RIG_MODEL(RIG_MODEL_HPSDR),
     .model_name = "PiHPSDR",
     .mfg_name =  "OpenHPSDR",
-    .version =  BACKEND_VER ".0",
+    .version =  BACKEND_VER ".1",
     .copyright =  "LGPL",
     .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -130,8 +130,8 @@ const struct rig_caps pihpsdr_caps =
     .parm_gran =  {},
     .vfo_ops =  PIHPSDR_VFO_OP,
     .scan_ops =  PIHPSDR_SCAN_OP,
-    .ctcss_list =  static_common_ctcss_list,
-    .dcs_list =  static_common_dcs_list,
+    .ctcss_list =  common_ctcss_list,
+    .dcs_list =  common_dcs_list,
     .preamp =   { 20, RIG_DBLST_END, }, /* FIXME: real preamp? */
     .attenuator =   { 20, RIG_DBLST_END, },
     .max_rit =  kHz(20),
@@ -843,7 +843,7 @@ int pihpsdr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         {
             int foundit = 0;
 
-            for (i = 0; i < MAXDBLSTSIZ && rig->state.attenuator[i]; i++)
+            for (i = 0; i < HAMLIB_MAXDBLSTSIZ && rig->state.attenuator[i]; i++)
             {
                 if (val.i == rig->state.attenuator[i])
                 {
@@ -872,7 +872,7 @@ int pihpsdr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         {
             int foundit = 0;
 
-            for (i = 0; i < MAXDBLSTSIZ && rig->state.preamp[i]; i++)
+            for (i = 0; i < HAMLIB_MAXDBLSTSIZ && rig->state.preamp[i]; i++)
             {
                 if (val.i == rig->state.preamp[i])
                 {
@@ -1117,7 +1117,7 @@ int pihpsdr_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
             return -RIG_ERJCTED;
         }
 
-        sscanf(lvlbuf + 3, "%d", &lvl);
+        sscanf(lvlbuf + 2, "%d", &lvl);
         val->f = lvl / 100.0; /* FIXME: for 1.2GHZ need to divide by 10 */
         break;
 
