@@ -309,7 +309,7 @@ th_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
         kmode = rmode2kenwood(mode, priv->mode_table);
 
-        if (kmode == -1)
+        if (kmode < 0)
         {
             rig_debug(RIG_DEBUG_WARN, "%s: Unsupported Mode value '%s'\n",
                       __func__, rig_strrmode(mode));
@@ -2532,8 +2532,6 @@ int th_get_ant(RIG *rig, vfo_t vfo, ant_t dummy, value_t *option,
 
     rig_debug(RIG_DEBUG_TRACE, "%s\n", __func__);
 
-    *ant_tx = *ant_rx = RIG_ANT_UNKNOWN;
-
     retval = kenwood_safe_transaction(rig, "ANT", buf, sizeof(buf), 5);
 
     if (retval != RIG_OK)
