@@ -161,13 +161,14 @@ static struct kenwood_priv_caps thd74_priv_caps =
 
 int thd74_open(RIG *rig)
 {
-    int ret;
-    struct kenwood_priv_data *priv = rig->state.priv;
-    strcpy(priv->verify_cmd, "ID\r");
+    //int ret;
+    //struct kenwood_priv_data *priv = rig->state.priv;
+    // this is already done in kenwood_init
+    //strcpy(priv->verify_cmd, "ID\r");
 
-    ret = kenwood_transaction(rig, "", NULL, 0);
+    //ret = kenwood_transaction(rig, "", NULL, 0);
 
-    return ret;
+    return RIG_OK;
 }
 
 
@@ -470,7 +471,7 @@ int thd74_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     {
         kmode = rmode2kenwood(mode, priv->mode_table);
 
-        if (kmode == -1)
+        if (kmode < 0)
         {
             rig_debug(RIG_DEBUG_WARN, "%s: Unsupported Mode value '%s'\n",
                       __func__, rig_strrmode(mode));
@@ -1642,9 +1643,9 @@ const struct rig_caps thd74_caps =
     RIG_MODEL(RIG_MODEL_THD74),
     .model_name = "TH-D74",
     .mfg_name =  "Kenwood",
-    .version =  BACKEND_VER ".0",
+    .version =  BACKEND_VER ".2",
     .copyright =  "LGPL",
-    .status =  RIG_STATUS_ALPHA,
+    .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_HANDHELD | RIG_FLAG_APRS | RIG_FLAG_TNC | RIG_FLAG_DXCLUSTER,
     .ptt_type =  RIG_PTT_RIG,
     .dcd_type =  RIG_DCD_RIG,
@@ -1726,7 +1727,7 @@ const struct rig_caps thd74_caps =
 
     .rig_init = kenwood_init,
     .rig_cleanup = kenwood_cleanup,
-    .rig_open = thd74_open,
+    .rig_open = kenwood_open,
     .set_freq = thd74_set_freq,
     .get_freq = thd74_get_freq,
     .set_mode = thd74_set_mode,
