@@ -1219,7 +1219,8 @@ int tmd710_get_dcs_sql(RIG *rig, vfo_t vfo, tone_t *code)
 
     if (fo_struct.dcs)
     {
-        *code = common_dcs_list[fo_struct.dcs_val];
+        tone_t *dcs_list = common_dcs_list;
+        *code = dcs_list[fo_struct.dcs_val];
     }
     else
     {
@@ -1234,9 +1235,11 @@ static int tmd710_find_dcs_index(tone_t code, uint32_t *dcs_index)
     int i = 0;
 
     // we only allow exact matches here
-    while (code != common_dcs_list[i])
+    tone_t *dcs_list = common_dcs_list;
+
+    while (code != dcs_list[i])
     {
-        if (common_dcs_list[i] == 0)
+        if (dcs_list[i] == 0)
         {
             return -RIG_EINVAL;
         }
@@ -1405,7 +1408,7 @@ static int tmd710_find_tuning_step_index(RIG *rig, shortfreq_t ts,
 {
     int k, stepind = -1;
 
-    for (k = 0; k < TSLSTSIZ; k++)
+    for (k = 0; k < HAMLIB_TSLSTSIZ; k++)
     {
         if ((rig->caps->tuning_steps[k].modes == RIG_MODE_NONE)
                 && (rig->caps->tuning_steps[k].ts == 0))
@@ -1889,7 +1892,8 @@ int tmd710_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
 
     if (me_struct.dcs)
     {
-        chan->dcs_sql = common_dcs_list[me_struct.dcs_val];
+        tone_t *dcs_list = common_dcs_list;
+        chan->dcs_sql = dcs_list[me_struct.dcs_val];
     }
     else
     {
