@@ -60,8 +60,27 @@
 #include "bandplan.h"
 #include "tones.h"
 
-/* prototypes */
+/*
+ * ft847 instance - private data
+ *
+ */
 
+struct ft847_priv_data
+{
+    split_t sat_mode;
+
+    unsigned char rx_status;  /* tx returned data */
+    unsigned char tx_status;  /* rx returned data */
+    /* for early ft847's we keep our own memory items */
+    /* Early rigs are one-way com to the rig */
+    freq_t freqA, freqB;
+    mode_t mode;
+    pbwidth_t width;
+    ptt_t ptt;
+};
+
+
+/* prototypes */
 static int ft847_send_priv_cmd(RIG *rig, int cmd_index);
 
 
@@ -193,7 +212,7 @@ static const yaesu_cmd_set_t ncmd[] =
  * 39 CTCSS sub-audible tones
  * c.f. ft847_set_ctcss_tone()
  */
-static const tone_t ft847_ctcss_list[] =
+static tone_t ft847_ctcss_list[] =
 {
     670,  693,  719,  744,  770,  797,  825,  854,  885,  915,
     948,  974, 1000, 1035, 1072, 1109, 1148, 1188, 1230, 1273,
@@ -214,7 +233,7 @@ const struct rig_caps ft847_caps =
     RIG_MODEL(RIG_MODEL_FT847),
     .model_name = "FT-847",
     .mfg_name =  "Yaesu",
-    .version =  "20200509.0",
+    .version =  "20210221.0",
     .copyright =  "LGPL",
     .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -371,7 +390,7 @@ const struct rig_caps ft847uni_caps =
     RIG_MODEL(RIG_MODEL_FT847UNI),
     .model_name = "FT-847UNI",
     .mfg_name =  "Yaesu",
-    .version =  "20200509.0",
+    .version =  "20210221.0",
     .copyright =  "LGPL",
     .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -1056,6 +1075,10 @@ int ft847_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 
 int ft847_set_split_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
+    int retval = rig_set_split_vfo(rig, RIG_VFO_A, RIG_SPLIT_ON, RIG_VFO_B);
+
+    if (retval != RIG_OK) { RETURNFUNC(retval); }
+
     return ft847_set_freq(rig, RIG_VFO_TX, freq);
 }
 
@@ -1342,11 +1365,6 @@ int ft847_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         return -RIG_ENIMPL;
     }
 
-    if (vfo != RIG_VFO_CURR)
-    {
-        return -RIG_ENTARGET;
-    }
-
     switch (level)
     {
     case RIG_LEVEL_STRENGTH:
@@ -1479,11 +1497,6 @@ int ft847_set_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t rptr_shift)
 {
     unsigned char cmd_index;  /* index of sequence to send */
 
-    if (vfo != RIG_VFO_CURR)
-    {
-        return -RIG_ENTARGET;
-    }
-
     switch (rptr_shift)
     {
     case RIG_RPT_SHIFT_NONE:
@@ -1514,11 +1527,6 @@ int ft847_set_rptr_offs(RIG *rig, vfo_t vfo, shortfreq_t rptr_offs)
         return -RIG_ENIMPL;
     }
 
-    if (vfo != RIG_VFO_CURR)
-    {
-        return -RIG_ENTARGET;
-    }
-
     memcpy(p_cmd, &ncmd[FT_847_NATIVE_CAT_SET_RPT_OFFSET].nseq, YAESU_CMD_LENGTH);
 
 
