@@ -151,7 +151,7 @@ const struct rig_caps ft920_caps =
     RIG_MODEL(RIG_MODEL_FT920),
     .model_name =       "FT-920",
     .mfg_name =         "Yaesu",
-    .version =          "20100823.0",           /* YYYYMMDD */
+    .version =          "20210221.0",           /* YYYYMMDD */
     .copyright =        "LGPL",
     .status =           RIG_STATUS_STABLE,
     .rig_type =         RIG_TYPE_TRANSCEIVER,
@@ -1460,6 +1460,10 @@ static int ft920_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed freq = %"PRIfreq" Hz\n", __func__,
               tx_freq);
 
+    err = rig_set_split_vfo(rig, RIG_VFO_A, RIG_SPLIT_ON, RIG_VFO_B);
+
+    if (err != RIG_OK) { RETURNFUNC(err); }
+
     priv = (struct ft920_priv_data *)rig->state.priv;
 
     err = ft920_get_split_vfo(rig, vfo, &priv->split, &priv->split_vfo);
