@@ -38,6 +38,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <fcntl.h>
 #include <stdio.h>
 #include <sys/types.h>
 
@@ -55,9 +56,9 @@
 #include <signal.h>
 #include <errno.h>
 
-
 #include <hamlib/rig.h>
 #include "event.h"
+#include "misc.h"
 
 #if defined(WIN32) && !defined(HAVE_TERMIOS_H)
 #  include "win32termios.h"
@@ -299,6 +300,8 @@ static int search_rig_and_decode(RIG *rig, rig_ptr_t data)
     struct timeval tv;
     int retval;
 
+    ENTERFUNC;
+
     /*
      * so far, only file oriented ports have event reporting support
      */
@@ -308,6 +311,23 @@ static int search_rig_and_decode(RIG *rig, rig_ptr_t data)
         return -1;
     }
 
+    /*
+     * TODO: FIXME: We may end up calling decode_event right before or after the hold_decode lock is released
+     *   by backend transaction routine. With the Icom backend this will end up waiting for the next CI-V frame
+     *   to be read and this will interfere with reading of the next response to any command.
+     *   => It is difficult to find a way to avoid this routine picking up regular responses.
+     */
+
+    /*
+     * Do not disturb, the backend is currently receiving data
+     */
+    if (rig->state.hold_decode)
+    {
+        rig_debug(RIG_DEBUG_TRACE, "%s: hold decode, backend is receiving data\n",
+                  __func__);
+        RETURNFUNC(-1);
+    }
+
     /* FIXME: siginfo is not portable, however use it where available */
 #if 0&&defined(HAVE_SIGINFO_T)
     siginfo_t *si = (siginfo_t *)data;
@@ -333,10 +353,10 @@ static int search_rig_and_decode(RIG *rig, rig_ptr_t data)
     if (retval < 0)
     {
         rig_debug(RIG_DEBUG_ERR,
-                  "%s: select: %s\n",
+                  "%s: select() failed: %s\n",
                   __func__,
                   strerror(errno));
-        return -1;
+        RETURNFUNC(-1);
     }
 
 #endif
@@ -346,7 +366,9 @@ static int search_rig_and_decode(RIG *rig, rig_ptr_t data)
      */
     if (rig->state.hold_decode)
     {
-        return -1;
+        rig_debug(RIG_DEBUG_TRACE, "%s: hold decode, backend is receiving data\n",
+                  __func__);
+        RETURNFUNC(-1);
     }
 
     if (rig->caps->decode_event)
@@ -354,7 +376,7 @@ static int search_rig_and_decode(RIG *rig, rig_ptr_t data)
         rig->caps->decode_event(rig);
     }
 
-    return 1;   /* process each opened rig */
+    RETURNFUNC(1);   /* process each opened rig */
 }
 
 
@@ -516,8 +538,8 @@ static void sa_sigalrmhandler(int signum)
  *
  *  Install a callback for freq events, to be called when in transceive mode.
  *
- * \return RIG_OK if the operation has been sucessful, otherwise
- * a negative value if an error occured (in which case, cause is
+ * \return RIG_OK if the operation has been successful, otherwise
+ * a negative value if an error occurred (in which case, cause is
  * set appropriately).
  *
  * \sa rig_set_trn()
@@ -546,8 +568,8 @@ int HAMLIB_API rig_set_freq_callback(RIG *rig, freq_cb_t cb, rig_ptr_t arg)
  *
  *  Install a callback for mode events, to be called when in transceive mode.
  *
- * \return RIG_OK if the operation has been sucessful, otherwise
- * a negative value if an error occured (in which case, cause is
+ * \return RIG_OK if the operation has been successful, otherwise
+ * a negative value if an error occurred (in which case, cause is
  * set appropriately).
  *
  * \sa rig_set_trn()
@@ -576,8 +598,8 @@ int HAMLIB_API rig_set_mode_callback(RIG *rig, mode_cb_t cb, rig_ptr_t arg)
  *
  *  Install a callback for vfo events, to be called when in transceive mode.
  *
- * \return RIG_OK if the operation has been sucessful, otherwise
- * a negative value if an error occured (in which case, cause is
+ * \return RIG_OK if the operation has been successful, otherwise
+ * a negative value if an error occurred (in which case, cause is
  * set appropriately).
  *
  * \sa rig_set_trn()
@@ -606,8 +628,8 @@ int HAMLIB_API rig_set_vfo_callback(RIG *rig, vfo_cb_t cb, rig_ptr_t arg)
  *
  *  Install a callback for ptt events, to be called when in transceive mode.
  *
- * \return RIG_OK if the operation has been sucessful, otherwise
- * a negative value if an error occured (in which case, cause is
+ * \return RIG_OK if the operation has been successful, otherwise
+ * a negative value if an error occurred (in which case, cause is
  * set appropriately).
  *
  * \sa rig_set_trn()
@@ -636,8 +658,8 @@ int HAMLIB_API rig_set_ptt_callback(RIG *rig, ptt_cb_t cb, rig_ptr_t arg)
  *
  *  Install a callback for dcd events, to be called when in transceive mode.
  *
- * \return RIG_OK if the operation has been sucessful, otherwise
- * a negative value if an error occured (in which case, cause is
+ * \return RIG_OK if the operation has been successful, otherwise
+ * a negative value if an error occurred (in which case, cause is
  * set appropriately).
  *
  * \sa rig_set_trn()
@@ -668,8 +690,8 @@ int HAMLIB_API rig_set_dcd_callback(RIG *rig, dcd_cb_t cb, rig_ptr_t arg)
  *  Install a callback for pipelined tuning module, to be called when the
  *  rig_scan( SCAN_PLT ) loop needs a new frequency, mode and width.
  *
- * \return RIG_OK if the operation has been sucessful, otherwise
- * a negative value if an error occured (in which case, cause is
+ * \return RIG_OK if the operation has been successful, otherwise
+ * a negative value if an error occurred (in which case, cause is
  * set appropriately).
  *
  * \sa rig_set_trn()
@@ -690,6 +712,37 @@ int HAMLIB_API rig_set_pltune_callback(RIG *rig, pltune_cb_t cb, rig_ptr_t arg)
 }
 
 
+/**
+ * \brief set the callback for spectrum line reception events
+ * \param rig   The rig handle
+ * \param cb    The callback to install
+ * \param arg   A Pointer to some private data to pass later on to the callback
+ *
+ *  Install a callback for spectrum line reception events, to be called when in transceive mode.
+ *
+ * \return RIG_OK if the operation has been successful, otherwise
+ * a negative value if an error occurred (in which case, cause is
+ * set appropriately).
+ *
+ * \sa rig_set_trn()
+ */
+int HAMLIB_API rig_set_spectrum_callback(RIG *rig, spectrum_cb_t cb,
+        rig_ptr_t arg)
+{
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
+    if (CHECK_RIG_ARG(rig))
+    {
+        return -RIG_EINVAL;
+    }
+
+    rig->callbacks.spectrum_event = cb;
+    rig->callbacks.spectrum_arg = arg;
+
+    return RIG_OK;
+}
+
+
 /**
  * \brief control the transceive mode
  * \param rig   The rig handle
@@ -697,8 +750,8 @@ int HAMLIB_API rig_set_pltune_callback(RIG *rig, pltune_cb_t cb, rig_ptr_t arg)
  *
  *  Enable/disable the transceive handling of a rig and kick off async mode.
  *
- * \return RIG_OK if the operation has been sucessful, otherwise
- * a negative value if an error occured (in which case, cause is
+ * \return RIG_OK if the operation has been successful, otherwise
+ * a negative value if an error occurred (in which case, cause is
  * set appropriately).
  *
  * \sa rig_get_trn()
@@ -729,7 +782,7 @@ int HAMLIB_API rig_set_trn(RIG *rig, int trn)
         }
         else
         {
-            /* when going POLL<->RIG, transtition to OFF */
+            /* when going POLL<->RIG, transition to OFF */
             retcode = rig_set_trn(rig, RIG_TRN_OFF);
 
             if (retcode != RIG_OK)
@@ -790,7 +843,8 @@ int HAMLIB_API rig_set_trn(RIG *rig, int trn)
         {
 #ifdef HAVE_SETITIMER
 
-            retcode = remove_trn_poll_rig(rig);
+            // don't care about the return code here
+            remove_trn_poll_rig(rig);
 
             value.it_value.tv_sec = 0;
             value.it_value.tv_usec = 0;
@@ -844,8 +898,8 @@ int HAMLIB_API rig_set_trn(RIG *rig, int trn)
  *  Retrieves the current status of the transceive mode, i.e. if radio
  *  sends new status automatically when some changes happened on the radio.
  *
- * \return RIG_OK if the operation has been sucessful, otherwise
- * a negative value if an error occured (in which case, cause is
+ * \return RIG_OK if the operation has been successful, otherwise
+ * a negative value if an error occurred (in which case, cause is
  * set appropriately).
  *
  * \sa rig_set_trn()
