@@ -1,5 +1,5 @@
 /*
- *  Hamlib Interface - extrq parameter interface
+ *  Hamlib Interface - rig ext parameter interface
  *  Copyright (c) 2000-2008 by Stephane Fillod
  *
  *
@@ -28,9 +28,9 @@
  * \file ext.c
  * \brief Extension request parameter interface
  *
- * An open-ended set of extension parameters and levels are available for each
- * rig, as provided in the rigcaps extparms and extlevels lists.  These
- * provide a way to work with rig-specific functions that don't fit into the
+ * An open-ended set of extension parameters, functions and levels are available
+ * for each rig, as provided in the rigcaps extparms, extfuncs and extlevels lists.
+ * These provide a way to work with rig-specific functions that don't fit into the
  * basic "virtual rig" of Hamlib.  See icom/ic746.c for an example.
  */
 
@@ -48,6 +48,79 @@
 
 #include "token.h"
 
+static int rig_has_ext_token(RIG *rig, token_t token)
+{
+    int *ext_tokens = rig->caps->ext_tokens;
+    int i;
+
+    if (ext_tokens == NULL)
+    {
+        // Assume that all listed extfuncs/extlevels/extparms are supported if
+        // the ext_tokens list is not defined to preserve backwards-compatibility
+        return 1;
+    }
+
+    for (i = 0; ext_tokens[i] != TOK_BACKEND_NONE; i++)
+    {
+        if (ext_tokens[i] == token)
+        {
+            return 1;
+        }
+    }
+
+    return 0;
+}
+
+
+/**
+ * \param rig The rig handle
+ * \param cfunc callback function of each extfunc
+ * \param data cookie to be passed to \a cfunc callback
+ * \brief Executes cfunc on all the elements stored in the extfuncs table
+ *
+ * The callback \a cfunc is called until it returns a value which is not
+ * strictly positive.  A zero value means a normal end of iteration, and a
+ * negative value an abnormal end, which will be the return value of
+ * rig_ext_func_foreach.
+ */
+int HAMLIB_API rig_ext_func_foreach(RIG *rig,
+                                    int (*cfunc)(RIG *,
+                                            const struct confparams *,
+                                            rig_ptr_t),
+                                    rig_ptr_t data)
+{
+    const struct confparams *cfp;
+
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
+    if (!rig || !rig->caps || !cfunc)
+    {
+        return -RIG_EINVAL;
+    }
+
+    for (cfp = rig->caps->extfuncs; cfp && cfp->name; cfp++)
+    {
+        if (!rig_has_ext_token(rig, cfp->token))
+        {
+            continue;
+        }
+
+        int ret = (*cfunc)(rig, cfp, data);
+
+        if (ret == 0)
+        {
+            return RIG_OK;
+        }
+
+        if (ret < 0)
+        {
+            return ret;
+        }
+    }
+
+    return RIG_OK;
+}
+
 
 /**
  * \param rig The rig handle
@@ -62,12 +135,11 @@
  */
 int HAMLIB_API rig_ext_level_foreach(RIG *rig,
                                      int (*cfunc)(RIG *,
-                                                  const struct confparams *,
-                                                  rig_ptr_t),
+                                             const struct confparams *,
+                                             rig_ptr_t),
                                      rig_ptr_t data)
 {
     const struct confparams *cfp;
-    int ret;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -78,7 +150,12 @@ int HAMLIB_API rig_ext_level_foreach(RIG *rig,
 
     for (cfp = rig->caps->extlevels; cfp && cfp->name; cfp++)
     {
-        ret = (*cfunc)(rig, cfp, data);
+        if (!rig_has_ext_token(rig, cfp->token))
+        {
+            continue;
+        }
+
+        int ret = (*cfunc)(rig, cfp, data);
 
         if (ret == 0)
         {
@@ -108,12 +185,11 @@ int HAMLIB_API rig_ext_level_foreach(RIG *rig,
  */
 int HAMLIB_API rig_ext_parm_foreach(RIG *rig,
                                     int (*cfunc)(RIG *,
-                                                 const struct confparams *,
-                                                 rig_ptr_t),
+                                            const struct confparams *,
+                                            rig_ptr_t),
                                     rig_ptr_t data)
 {
     const struct confparams *cfp;
-    int ret;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -124,7 +200,12 @@ int HAMLIB_API rig_ext_parm_foreach(RIG *rig,
 
     for (cfp = rig->caps->extparms; cfp && cfp->name; cfp++)
     {
-        ret = (*cfunc)(rig, cfp, data);
+        if (!rig_has_ext_token(rig, cfp->token))
+        {
+            continue;
+        }
+
+        int ret = (*cfunc)(rig, cfp, data);
 
         if (ret == 0)
         {
@@ -146,7 +227,7 @@ int HAMLIB_API rig_ext_parm_foreach(RIG *rig,
  * \param name
  * \brief lookup ext token by its name, return pointer to confparams struct.
  *
- * Lookup extlevels table first, then fall back to extparms.
+ * Lookup extlevels table, then extfuncs, then extparms.
  *
  * Returns NULL if nothing found
  *
@@ -171,6 +252,14 @@ const struct confparams *HAMLIB_API rig_ext_lookup(RIG *rig, const char *name)
         }
     }
 
+    for (cfp = rig->caps->extfuncs; cfp && cfp->name; cfp++)
+    {
+        if (!strcmp(cfp->name, name))
+        {
+            return cfp;
+        }
+    }
+
     for (cfp = rig->caps->extparms; cfp && cfp->name; cfp++)
     {
         if (!strcmp(cfp->name, name))
@@ -182,17 +271,16 @@ const struct confparams *HAMLIB_API rig_ext_lookup(RIG *rig, const char *name)
     return NULL;
 }
 
-
 /**
  * \param rig
  * \param token
  * \brief lookup ext token, return pointer to confparams struct.
  *
- * lookup extlevels table first, then fall back to extparms.
+ * lookup extlevels table first, then extfuncs, then fall back to extparms.
  *
  * Returns NULL if nothing found
  */
-const struct confparams * HAMLIB_API rig_ext_lookup_tok(RIG *rig, token_t token)
+const struct confparams *HAMLIB_API rig_ext_lookup_tok(RIG *rig, token_t token)
 {
     const struct confparams *cfp;
 
@@ -211,6 +299,14 @@ const struct confparams * HAMLIB_API rig_ext_lookup_tok(RIG *rig, token_t token)
         }
     }
 
+    for (cfp = rig->caps->extfuncs; cfp && cfp->token; cfp++)
+    {
+        if (cfp->token == token)
+        {
+            return cfp;
+        }
+    }
+
     for (cfp = rig->caps->extparms; cfp && cfp->token; cfp++)
     {
         if (cfp->token == token)
@@ -226,7 +322,7 @@ const struct confparams * HAMLIB_API rig_ext_lookup_tok(RIG *rig, token_t token)
 /**
  * \param rig
  * \param name
- * \brief Simple lookup returning token id assicated with name
+ * \brief Simple lookup returning token id associated with name
  */
 token_t HAMLIB_API rig_ext_token_lookup(RIG *rig, const char *name)
 {
