@@ -65,7 +65,7 @@ int HAMLIB_API port_open(hamlib_port_t *p)
     int status;
     int want_state_delay = 0;
 
-    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+    ENTERFUNC;
 
     p->fd = -1;
 
@@ -76,7 +76,9 @@ int HAMLIB_API port_open(hamlib_port_t *p)
 
         if (status < 0)
         {
-            return status;
+            rig_debug(RIG_DEBUG_ERR, "%s: serial_open(%s) status=%d, err=%s\n", __func__,
+                      p->pathname, status, strerror(errno));
+            RETURNFUNC(status);
         }
 
         if (p->parm.serial.rts_state != RIG_SIGNAL_UNSET
@@ -89,7 +91,8 @@ int HAMLIB_API port_open(hamlib_port_t *p)
 
         if (status != 0)
         {
-            return status;
+            rig_debug(RIG_DEBUG_ERR, "%s: set_rts status=%d\n", __func__, status);
+            RETURNFUNC(status);
         }
 
         if (p->parm.serial.dtr_state != RIG_SIGNAL_UNSET)
@@ -101,7 +104,8 @@ int HAMLIB_API port_open(hamlib_port_t *p)
 
         if (status != 0)
         {
-            return status;
+            rig_debug(RIG_DEBUG_ERR, "%s: set_dtr status=%d\n", __func__, status);
+            RETURNFUNC(status);
         }
 
         /*
@@ -120,7 +124,7 @@ int HAMLIB_API port_open(hamlib_port_t *p)
 
         if (status < 0)
         {
-            return status;
+            RETURNFUNC(status);
         }
 
         break;
@@ -130,7 +134,7 @@ int HAMLIB_API port_open(hamlib_port_t *p)
 
         if (status < 0)
         {
-            return status;
+            RETURNFUNC(status);
         }
 
         break;
@@ -140,21 +144,24 @@ int HAMLIB_API port_open(hamlib_port_t *p)
 
         if (status < 0)
         {
-            return -RIG_EIO;
+            RETURNFUNC(-RIG_EIO);
         }
 
         p->fd = status;
         break;
 
+#if defined(HAVE_LIBUSB_H) || defined (HAVE_LIBUSB_1_0_LIBUSB_H)
+
     case RIG_PORT_USB:
         status = usb_port_open(p);
 
         if (status < 0)
         {
-            return status;
+            RETURNFUNC(status);
         }
 
         break;
+#endif
 
     case RIG_PORT_NONE:
     case RIG_PORT_RPC:
@@ -167,16 +174,16 @@ int HAMLIB_API port_open(hamlib_port_t *p)
 
         if (status < 0)
         {
-            return status;
+            RETURNFUNC(status);
         }
 
         break;
 
     default:
-        return -RIG_EINVAL;
+        RETURNFUNC(-RIG_EINVAL);
     }
 
-    return RIG_OK;
+    RETURNFUNC(RIG_OK);
 }
 
 
@@ -190,7 +197,7 @@ int HAMLIB_API port_close(hamlib_port_t *p, rig_port_t port_type)
 {
     int ret = RIG_OK;
 
-    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+    ENTERFUNC;
 
     if (p->fd != -1)
     {
@@ -200,9 +207,12 @@ int HAMLIB_API port_close(hamlib_port_t *p, rig_port_t port_type)
             ret = ser_close(p);
             break;
 
+#if defined(HAVE_LIBUSB_H) || defined (HAVE_LIBUSB_1_0_LIBUSB_H)
+
         case RIG_PORT_USB:
             ret = usb_port_close(p);
             break;
+#endif
 
         case RIG_PORT_NETWORK:
         case RIG_PORT_UDP_NETWORK:
@@ -221,7 +231,7 @@ int HAMLIB_API port_close(hamlib_port_t *p, rig_port_t port_type)
         p->fd = -1;
     }
 
-    return ret;
+    RETURNFUNC(ret);
 }
 
 
@@ -238,6 +248,7 @@ static ssize_t port_read(hamlib_port_t *p, void *buf, size_t count)
     int i;
     ssize_t ret;
 
+    //ENTERFUNC; // too verbose
     /*
      * Since WIN32 does its special serial read, we have
      * to catch the microHam case to do just "read".
@@ -264,6 +275,7 @@ static ssize_t port_read(hamlib_port_t *p, void *buf, size_t count)
             }
         }
 
+        //RETURNFUNC(ret); // too verbose
         return ret;
     }
     else if (p->type.rig == RIG_PORT_NETWORK
@@ -422,7 +434,7 @@ int HAMLIB_API write_block(hamlib_port_t *p, const char *txbuffer, size_t count)
 {
     int ret;
 
-    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+    //rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
 #ifdef WANT_NON_ACTIVE_POST_WRITE_DELAY
 
@@ -470,7 +482,7 @@ int HAMLIB_API write_block(hamlib_port_t *p, const char *txbuffer, size_t count)
                 return -RIG_EIO;
             }
 
-            hl_usleep(p->write_delay * 1000);
+            if (p->write_delay > 0) { hl_usleep(p->write_delay * 1000); }
         }
     }
     else
@@ -713,10 +725,10 @@ int HAMLIB_API read_string(hamlib_port_t *p,
 
                 dump_hex((unsigned char *) rxbuffer, total_count);
                 rig_debug(RIG_DEBUG_WARN,
-                          "%s(): Timed out %d.%d seconds after %d chars\n",
+                          "%s(): Timed out %d.%03d seconds after %d chars\n",
                           __func__,
                           (int)elapsed_time.tv_sec,
-                          (int)elapsed_time.tv_usec,
+                          (int)elapsed_time.tv_usec / 1000,
                           total_count);
 
                 return -RIG_ETIMEOUT;
