@@ -76,6 +76,7 @@
 #  include <dev/ppbus/ppbconf.h>
 #endif
 
+//! @cond Doxygen_Suppress
 /*
  * These control port bits are active low.
  * We toggle them so that this weirdness doesn't get propagated
@@ -89,6 +90,7 @@
  * through our interface.
  */
 #define SP_ACTIVE_LOW_BITS  0x80
+//! @endcond
 
 /*
    Pinout table of parallel port from http://en.wikipedia.org/wiki/Parallel_port#Pinouts
@@ -127,17 +129,17 @@
 int par_open(hamlib_port_t *port)
 {
     int fd;
-
-    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
-
 #ifdef HAVE_LINUX_PPDEV_H
     int mode;
 #endif
 
 #if defined (__WIN64__) || defined(__WIN32__)
+    // cppcheck-suppress *
     HANDLE handle;
 #endif
 
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
     if (!port->pathname[0])
     {
         return -RIG_EINVAL;
@@ -207,6 +209,7 @@ int par_open(hamlib_port_t *port)
     }
 
 #else
+    port->fd = fd = 0;
     return -RIG_ENIMPL;
 #endif
     port->fd = fd;
@@ -240,20 +243,24 @@ int par_close(hamlib_port_t *port)
  */
 int HAMLIB_API par_write_data(hamlib_port_t *port, unsigned char data)
 {
-    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
-
 #ifdef HAVE_LINUX_PPDEV_H
     int status;
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
     status = ioctl(port->fd, PPWDATA, &data);
     return status == 0 ? RIG_OK : -RIG_EIO;
 #elif defined(HAVE_DEV_PPBUS_PPI_H)
     int status;
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
     status = ioctl(port->fd, PPISDATA, &data);
     return status == 0 ? RIG_OK : -RIG_EIO;
 #elif defined(__WIN64__) || defined(__WIN32__)
-    unsigned int dummy;
+    unsigned int dummy = 0;
 
     intptr_t handle;
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
 
     handle = _get_osfhandle(port->fd);
 
@@ -281,22 +288,26 @@ int HAMLIB_API par_write_data(hamlib_port_t *port, unsigned char data)
  */
 int HAMLIB_API par_read_data(hamlib_port_t *port, unsigned char *data)
 {
-    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
-
 #ifdef HAVE_LINUX_PPDEV_H
     int status;
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
     status = ioctl(port->fd, PPRDATA, data);
     return status == 0 ? RIG_OK : -RIG_EIO;
 #elif defined(HAVE_DEV_PPBUS_PPI_H)
     int status;
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
     status = ioctl(port->fd, PPIGDATA, &data);
     return status == 0 ? RIG_OK : -RIG_EIO;
 #elif defined(__WIN64__) || defined(__WIN32__)
-    unsigned char ret;
-    unsigned int dummy;
+    unsigned char ret = 0;
+    unsigned int dummy = 0;
 
     intptr_t handle;
 
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
     handle = _get_osfhandle(port->fd);
 
     if (handle != (intptr_t)INVALID_HANDLE_VALUE)
@@ -333,13 +344,13 @@ int HAMLIB_API par_read_data(hamlib_port_t *port, unsigned char *data)
  */
 int HAMLIB_API par_write_control(hamlib_port_t *port, unsigned char control)
 {
-    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
-
 #ifdef HAVE_LINUX_PPDEV_H
     int status;
     unsigned char ctrl = control ^ CP_ACTIVE_LOW_BITS;
     status = ioctl(port->fd, PPWCONTROL, &ctrl);
 
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
     if (status < 0)
     {
         rig_debug(RIG_DEBUG_ERR,
@@ -352,18 +363,22 @@ int HAMLIB_API par_write_control(hamlib_port_t *port, unsigned char control)
 #elif defined(HAVE_DEV_PPBUS_PPI_H)
     int status;
     unsigned char ctrl = control ^ CP_ACTIVE_LOW_BITS;
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
     status = ioctl(port->fd, PPISCTRL, &ctrl);
     return status == 0 ? RIG_OK : -RIG_EIO;
 #elif defined(__WIN64__) || defined(__WIN32__)
     unsigned char ctr = control;
     unsigned char dummyc;
-    unsigned int dummy;
+    unsigned int dummy = 0;
     const unsigned char wm = (C1284_NSTROBE
                               | C1284_NAUTOFD
                               | C1284_NINIT
                               | C1284_NSELECTIN);
     intptr_t handle;
 
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
     if (ctr & 0x20)
     {
         rig_debug(RIG_DEBUG_WARN,
@@ -409,11 +424,12 @@ int HAMLIB_API par_write_control(hamlib_port_t *port, unsigned char control)
  */
 int HAMLIB_API par_read_control(hamlib_port_t *port, unsigned char *control)
 {
-    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
 #ifdef HAVE_LINUX_PPDEV_H
     int status;
     unsigned char ctrl;
+
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
     status = ioctl(port->fd, PPRCONTROL, &ctrl);
 
     if (status < 0)
@@ -429,15 +445,18 @@ int HAMLIB_API par_read_control(hamlib_port_t *port, unsigned char *control)
 #elif defined(HAVE_DEV_PPBUS_PPI_H)
     int status;
     unsigned char ctrl;
+
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
     status = ioctl(port->fd, PPIGCTRL, &ctrl);
     *control = ctrl ^ CP_ACTIVE_LOW_BITS;
     return status == 0 ? RIG_OK : -RIG_EIO;
 #elif defined(__WIN64__) || defined(__WIN32__)
-    unsigned char ret;
-    unsigned int dummy;
+    unsigned char ret = 0;
+    unsigned int dummy = 0;
 
     intptr_t handle;
 
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
     handle = _get_osfhandle(port->fd);
 
     if (handle != (intptr_t)INVALID_HANDLE_VALUE)
@@ -476,12 +495,12 @@ int HAMLIB_API par_read_control(hamlib_port_t *port, unsigned char *control)
  */
 int HAMLIB_API par_read_status(hamlib_port_t *port, unsigned char *status)
 {
-    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
 #ifdef HAVE_LINUX_PPDEV_H
     int ret;
     unsigned char sta;
 
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
     ret = ioctl(port->fd, PPRSTATUS, &sta);
     *status = sta ^ SP_ACTIVE_LOW_BITS;
     return ret == 0 ? RIG_OK : -RIG_EIO;
@@ -490,16 +509,18 @@ int HAMLIB_API par_read_status(hamlib_port_t *port, unsigned char *status)
     int ret;
     unsigned char sta;
 
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
     ret = ioctl(port->fd, PPIGSTATUS, &sta);
     *status = sta ^ SP_ACTIVE_LOW_BITS;
     return ret == 0 ? RIG_OK : -RIG_EIO;
 
 #elif defined(__WIN64__) || defined(__WIN32__)
-    unsigned char ret;
-    unsigned int dummy;
+    unsigned char ret = 0;
+    unsigned int dummy = 0;
 
     intptr_t handle;
 
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
     handle = _get_osfhandle(port->fd);
 
     if (handle != (intptr_t)INVALID_HANDLE_VALUE)
@@ -681,15 +702,19 @@ int par_ptt_get(hamlib_port_t *p, ptt_t *pttx)
         status = par_read_control(p, &ctl);
         par_unlock(p);
 
-        *pttx = (ctl & PARPORT_CONTROL_INIT) &&
-                !(ctl & PARPORT_CONTROL_STROBE) ?
-                RIG_PTT_ON : RIG_PTT_OFF;
+        if (status == RIG_OK)
+        {
+            *pttx = (ctl & PARPORT_CONTROL_INIT) &&
+                    !(ctl & PARPORT_CONTROL_STROBE) ?
+                    RIG_PTT_ON : RIG_PTT_OFF;
+        }
+
         return status;
     }
 
     default:
         rig_debug(RIG_DEBUG_ERR,
-                  "Unsupported PTT type %d\n",
+                  "%s: unsupported PTT type %d\n",
                   __func__,
                   p->type.ptt);
         return -RIG_ENAVAIL;
@@ -717,8 +742,13 @@ int par_dcd_get(hamlib_port_t *p, dcd_t *dcdx)
         int status;
 
         status = par_read_data(p, &reg);
-        *dcdx = reg & (1 << p->parm.parallel.pin) ?
-                RIG_DCD_ON : RIG_DCD_OFF;
+
+        if (status == RIG_OK)
+        {
+            *dcdx = (reg & (1 << p->parm.parallel.pin)) ?
+                    RIG_DCD_ON : RIG_DCD_OFF;
+        }
+
         return status;
     }
 
