@@ -24,6 +24,8 @@
 
 #include <hamlib/rig.h>
 #include <hamlib/rotator.h>
+#include <hamlib/amplifier.h>
+#include <config.h>
 
 #ifdef __cplusplus
 #define EXTERN_C extern "C"
@@ -69,4 +71,19 @@
                               rig_probe_func_t cfunc,   \
                               rig_ptr_t data))
 
+#define PREFIX_INITAMPS initamps
+#define PREFIX_PROBEAMPS probeallamps
+
+#define DECLARE_INITAMP_BACKEND(backend)                                \
+    EXTERN_C BACKEND_EXPORT(int)                                        \
+    MAKE_VERSIONED_FN(PREFIX_INITAMPS, ABI_VERSION, backend(void *be_handle))
+
+#define DECLARE_PROBEAMP_BACKEND(backend)               \
+    EXTERN_C BACKEND_EXPORT(amp_model_t)                \
+    MAKE_VERSIONED_FN(PREFIX_PROBEAMPS,                 \
+                      ABI_VERSION,                      \
+                      backend(hamlib_port_t *port,      \
+                              rig_probe_func_t cfunc,   \
+                              rig_ptr_t data))
+
 #endif  /* _REGISTER_H */
