@@ -84,6 +84,8 @@ DEFINE_INITROT_BACKEND(cnctrk);
 DEFINE_INITROT_BACKEND(prosistel);
 DEFINE_INITROT_BACKEND(meade);
 DEFINE_INITROT_BACKEND(ioptron);
+DEFINE_INITROT_BACKEND(satel);
+DEFINE_INITROT_BACKEND(radant);
 #if HAVE_LIBINDI
 DEFINE_INITROT_BACKEND(indi);
 #endif
@@ -126,6 +128,8 @@ static struct
     { ROT_PROSISTEL, ROT_BACKEND_PROSISTEL, ROT_FUNCNAMA(prosistel) },
     { ROT_MEADE, ROT_BACKEND_MEADE, ROT_FUNCNAMA(meade) },
     { ROT_IOPTRON, ROT_BACKEND_IOPTRON, ROT_FUNCNAMA(ioptron) },
+    { ROT_SATEL, ROT_BACKEND_SATEL, ROT_FUNCNAMA(satel) },
+    { ROT_RADANT, ROT_BACKEND_RADANT, ROT_FUNCNAMA(radant)},
 #if HAVE_LIBINDI
     { ROT_INDI, ROT_BACKEND_INDI, ROT_FUNCNAMA(indi) },
 #endif
