@@ -35,21 +35,16 @@
 #  include "config.h"
 #endif
 
-#include <hamlib/rig.h>
-
-/*
- * Compile only if libusb is available
- */
-#if defined(HAVE_LIBUSB) && (defined(HAVE_LIBUSB_H) || defined(HAVE_LIBUSB_1_0_LIBUSB_H))
 
 
 #include <stdlib.h>
 #include <stdio.h>   /* Standard input/output definitions */
 #include <string.h>  /* String function definitions */
-#include <unistd.h>  /* UNIX standard function definitions */
+#include <unistd.h>
 #include <errno.h>
 #include <sys/types.h>
-#include <unistd.h>
+
+#include <hamlib/rig.h>
 
 #ifdef HAVE_LIBUSB_H
 #  include <libusb.h>
@@ -59,6 +54,10 @@
 
 #include "usb_port.h"
 
+/*
+ * Compile only if libusb is available
+ */
+#if defined(HAVE_LIBUSB) && (defined(HAVE_LIBUSB_H) || defined(HAVE_LIBUSB_1_0_LIBUSB_H))
 
 /**
  * \brief Find and open USB device
@@ -104,7 +103,7 @@ static libusb_device_handle *find_and_open_device(const hamlib_port_t *port)
                   desc.idProduct);
 
         if (desc.idVendor == port->parm.usb.vid
-            && desc.idProduct == port->parm.usb.pid)
+                && desc.idProduct == port->parm.usb.pid)
         {
 
             /* we need to open the device in order to query strings */
@@ -185,7 +184,7 @@ static libusb_device_handle *find_and_open_device(const hamlib_port_t *port)
                      */
                     if (strncasecmp(string,
                                     port->parm.usb.product,
-                                    sizeof(port->parm.usb.product - 1)) != 0)
+                                    sizeof(port->parm.usb.product) - 1) != 0)
                     {
 
                         rig_debug(RIG_DEBUG_WARN,
@@ -200,7 +199,7 @@ static libusb_device_handle *find_and_open_device(const hamlib_port_t *port)
 
             libusb_free_device_list(devs, 1);
 
-            rig_debug(RIG_DEBUG_VERBOSE, " -> found\n");
+            rig_debug(RIG_DEBUG_VERBOSE, "%s", " -> found\n");
 
             return udh;
         }
@@ -208,7 +207,7 @@ static libusb_device_handle *find_and_open_device(const hamlib_port_t *port)
 
     libusb_free_device_list(devs, 1);
 
-    rig_debug(RIG_DEBUG_VERBOSE, " -> not found\n");
+    rig_debug(RIG_DEBUG_VERBOSE, "%s", " -> not found\n");
 
     return NULL;        /* not found */
 }
@@ -221,14 +220,14 @@ static libusb_device_handle *find_and_open_device(const hamlib_port_t *port)
  */
 int usb_port_open(hamlib_port_t *port)
 {
-    static char pathname[FILPATHLEN];
+    static char pathname[HAMLIB_FILPATHLEN];
     libusb_device_handle *udh;
     char *p, *q;
     int r;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
-    /* init defaut libusb-1.0 library contexte, if needed */
+    /* init default libusb-1.0 library contexte, if needed */
     r = libusb_init(NULL);
 
     if (r < 0)
@@ -246,7 +245,7 @@ int usb_port_open(hamlib_port_t *port)
     /* Extract VID/PID/Vendor/Product name from pathname. */
     /* Duplicate the string since we may modify it. */
     strncpy(pathname, port->pathname, sizeof pathname);
-    pathname[FILPATHLEN - 1] = '\0';
+    pathname[HAMLIB_FILPATHLEN - 1] = '\0';
 
     p = pathname;
     q = strchr(p, ':');
@@ -376,10 +375,11 @@ int usb_port_open(hamlib_port_t *port)
  */
 int usb_port_close(hamlib_port_t *port)
 {
-    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
     libusb_device_handle *udh = port->handle;
 
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
     libusb_release_interface(udh, port->parm.usb.iface);
 
     libusb_close(udh);
@@ -391,20 +391,24 @@ int usb_port_close(hamlib_port_t *port)
 
 #else
 
+//! @cond Doxygen_Suppress
 int usb_port_open(hamlib_port_t *port)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
     return -RIG_ENAVAIL;
 }
+//! @endcond
 
 
+//! @cond Doxygen_Suppress
 int usb_port_close(hamlib_port_t *port)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
     return -RIG_ENAVAIL;
 }
+//! @endcond
 
 #endif  /* defined(HAVE_LIBUSB) && defined(HAVE_LIBUSB_H) */
 
