@@ -63,7 +63,7 @@ static int set_channel_data(RIG *rig,
                             char **line_key,
                             char **line_data);
 
-static char * mystrtok(char *s, char delim);
+static char *mystrtok(char *s, char delim);
 
 static int  tokenize_line(char *line,
                           char **token_list,
@@ -97,7 +97,7 @@ int csv_save(RIG *rig, const char *outfilename)
                rig->caps->clone_combo_get);
     }
 
-    status = rig_get_chan_all_cb(rig, dump_csv_chan, f);
+    status = rig_get_chan_all_cb(rig, RIG_VFO_NONE, dump_csv_chan, f);
 
     fclose(f);
 
@@ -175,7 +175,7 @@ int csv_load(RIG *rig, const char *infilename)
         set_channel_data(rig, &chan, key_list, value_list);
 
         /* Write a rig memory */
-        status = rig_set_channel(rig, &chan);
+        status = rig_set_channel(rig, RIG_VFO_NONE, &chan);
 
         if (status != RIG_OK)
         {
@@ -197,7 +197,7 @@ int csv_load(RIG *rig, const char *infilename)
     \param line (input) - a line to be tokenized, the line will be modified!
     \param token_list (output) - a resulting table containing pointers to
          tokens, or NULLs (the table will be initially nulled )
-         all the pointers schould point to addresses within the line
+         all the pointers should point to addresses within the line
     \param siz (input) - size of the table
     \param delim (input) - delimiter character
     \return number of tokens on success, 0 if \param token_list is too small to contain all the tokens,
@@ -267,10 +267,11 @@ static int tokenize_line(char *line, char **token_list, size_t siz, char delim)
     \return pointer to token, or NULL if there are no more tokens
     \sa "man strtok"
     */
-static char * mystrtok(char *s, char delim)
+static char *mystrtok(char *s, char delim)
 {
     static size_t pos = 0, length = 0;
     static char *str = 0;
+    size_t i, ent_pos;
 
     if (s != NULL)
     {
@@ -282,12 +283,12 @@ static char * mystrtok(char *s, char delim)
     {
     }
 
-    if (str[ pos + 1 ] == '\0')
+    if (str && str[ pos + 1 ] == '\0')
     {
         return NULL;
     }
 
-    size_t i, ent_pos = pos;
+    ent_pos = pos;
 
     for (i = pos; i < length;)
     {
@@ -303,6 +304,7 @@ static char * mystrtok(char *s, char delim)
         }
     }
 
+    // cppcheck-suppress *
     return str + ent_pos;
 }
 
@@ -350,7 +352,7 @@ int csv_parm_save(RIG *rig, const char *outfilename)
 {
     int i, ret;
     FILE *f;
-    setting_t parm, get_parm = all ? 0x7fffffff : rig->state.has_get_parm;
+    setting_t get_parm = all ? 0x7fffffff : rig->state.has_get_parm;
 
     f = fopen(outfilename, "w");
 
@@ -378,6 +380,7 @@ int csv_parm_save(RIG *rig, const char *outfilename)
     {
         const char *ms;
         value_t val;
+        setting_t parm;
 
         parm = get_parm & rig_idx2setting(i);
         ms = rig_strparm(parm);
@@ -599,12 +602,12 @@ int dump_csv_chan(RIG *rig,
 
     if (mem_caps->ant)
     {
-        fprintf(f, "%d%c", chan.ant, csv_sep);
+        fprintf(f, "%u%c", chan.ant, csv_sep);
     }
 
     if (mem_caps->freq)
     {
-        fprintf(f, "%.0"PRIfreq"%c", chan.freq, csv_sep);
+        fprintf(f, "%"PRIfreq"%c", chan.freq, csv_sep);
     }
 
     if (mem_caps->mode)
@@ -619,7 +622,7 @@ int dump_csv_chan(RIG *rig,
 
     if (mem_caps->tx_freq)
     {
-        fprintf(f, "%.0"PRIfreq"%c", chan.tx_freq, csv_sep);
+        fprintf(f, "%"PRIfreq"%c", chan.tx_freq, csv_sep);
     }
 
     if (mem_caps->tx_mode)
@@ -669,27 +672,27 @@ int dump_csv_chan(RIG *rig,
 
     if (mem_caps->funcs)
     {
-        fprintf(f, "%lx%c", chan.funcs, csv_sep);
+        fprintf(f, "%"PRXll"%c", chan.funcs, csv_sep);
     }
 
     if (mem_caps->ctcss_tone)
     {
-        fprintf(f, "%d%c", chan.ctcss_tone, csv_sep);
+        fprintf(f, "%u%c", chan.ctcss_tone, csv_sep);
     }
 
     if (mem_caps->ctcss_sql)
     {
-        fprintf(f, "%d%c", chan.ctcss_sql, csv_sep);
+        fprintf(f, "%u%c", chan.ctcss_sql, csv_sep);
     }
 
     if (mem_caps->dcs_code)
     {
-        fprintf(f, "%d%c", chan.dcs_code, csv_sep);
+        fprintf(f, "%u%c", chan.dcs_code, csv_sep);
     }
 
     if (mem_caps->dcs_sql)
     {
-        fprintf(f, "%d%c", chan.dcs_sql, csv_sep);
+        fprintf(f, "%u%c", chan.dcs_sql, csv_sep);
     }
 
     if (mem_caps->scan_group)
@@ -729,6 +732,7 @@ int set_channel_data(RIG *rig,
 {
 
     int i, j, n;
+    const channel_cap_t *mem_caps;
 
     memset(chan, 0, sizeof(channel_t));
     chan->vfo = RIG_VFO_CURR;
@@ -743,18 +747,23 @@ int set_channel_data(RIG *rig,
 
     n = chan->channel_num = atoi(line_data_list[ i ]);
 
-    /* find chanel caps of appropriate memory group? */
-    for (j = 0; j < CHANLSTSIZ; j++)
+    /* find channel caps of appropriate memory group? */
+    for (j = 0; j < HAMLIB_CHANLSTSIZ; j++)
     {
-        if (rig->state.chan_list[j].start <= n && rig->state.chan_list[j].end >= n)
+        if (rig->state.chan_list[j].startc <= n && rig->state.chan_list[j].endc >= n)
         {
             break;
         }
     }
 
+    if (j == HAMLIB_CHANLSTSIZ)
+    {
+        return -RIG_EINVAL;
+    }
+
     printf("Requested channel number %d, list number %d\n", n, j);
 
-    const channel_cap_t *mem_caps = &rig->state.chan_list[j].mem_caps;
+    mem_caps = &rig->state.chan_list[j].mem_caps;
 
     if (mem_caps->bank_num)
     {
@@ -940,7 +949,7 @@ int set_channel_data(RIG *rig,
 
         if (i >= 0)
         {
-            sscanf(line_data_list[i], "%lx", &chan->funcs);
+            sscanf(line_data_list[i], "%"SCNXll, &chan->funcs);
         }
     }
 
@@ -1023,6 +1032,11 @@ int find_on_list(char **list, char *what)
         return -1;
     }
 
+    if (!list[i])
+    {
+        return -1;
+    }
+
     while (list[i] != NULL)
     {
         if (strcmp(list[i], what) == 0)
@@ -1035,12 +1049,5 @@ int find_on_list(char **list, char *what)
         }
     }
 
-    if (!list[i])
-    {
-        return -1;
-    }
-    else
-    {
-        return i;
-    }
+    return i;
 }
