@@ -86,7 +86,7 @@ static void usage(void);
  * NB: do NOT use -W since it's reserved by POSIX.
  * TODO: add an option to read from a file
  */
-#define SHORT_OPTIONS "+m:r:p:d:P:D:s:c:t:lC:LuonvhVZ"
+#define SHORT_OPTIONS "+m:r:p:d:P:D:s:c:t:lC:LuonvhVYZ!"
 static struct option long_options[] =
 {
     {"model",           1, 0, 'm'},
@@ -104,7 +104,7 @@ static struct option long_options[] =
     {"dump-caps",       0, 0, 'u'},
     {"vfo",             0, 0, 'o'},
     {"no-restore-ai",   0, 0, 'n'},
-    {"ignore rig open error", 0, 0, 'Y'},
+    {"ignore-err",      0, 0, 'Y'},
     {"debug-time-stamps", 0, 0, 'Z'},
 #ifdef HAVE_READLINE_HISTORY
     {"read-history",    0, 0, 'i'},
@@ -113,6 +113,7 @@ static struct option long_options[] =
     {"verbose",         0, 0, 'v'},
     {"help",            0, 0, 'h'},
     {"version",         0, 0, 'V'},
+    {"cookie",          0, 0, '!'},
     {0, 0, 0, 0}
 
 };
@@ -152,6 +153,8 @@ int main(int argc, char *argv[])
     char send_cmd_term = '\r';  /* send_cmd termination char */
     int ext_resp = 0;
     char resp_sep = '\n';
+    int i;
+    char rigstartup[1024];
 
     while (1)
     {
@@ -172,12 +175,16 @@ int main(int argc, char *argv[])
 
         switch (c)
         {
+        case '!':
+            cookie_use = 1;
+            break;
+
         case 'h':
             usage();
             exit(0);
 
         case 'V':
-            version();
+            printf("rigctl %s\n", hamlib_version2);
             exit(0);
 
         case 'm':
@@ -420,6 +427,7 @@ int main(int argc, char *argv[])
 
         case 'Y':
             ignore_rig_open_error = 1;
+            break;
 
         case 'Z':
             rig_set_debug_time_stamp(1);
@@ -433,8 +441,14 @@ int main(int argc, char *argv[])
 
     rig_set_debug(verbose);
 
-    rig_debug(RIG_DEBUG_VERBOSE, "rigctl %s\nLast commit was %s\n", hamlib_version,
-              HAMLIBDATETIME);
+    snprintf(rigstartup, sizeof(rigstartup), "%s(%d) Startup:", __FILE__, __LINE__);
+
+    for (i = 0; i < argc; ++i) { strcat(rigstartup, " "); strcat(rigstartup, argv[i]); }
+
+    rig_debug(RIG_DEBUG_VERBOSE, "%s\n", rigstartup);
+
+
+    rig_debug(RIG_DEBUG_VERBOSE, "rigctl %s\n", hamlib_version2);
     rig_debug(RIG_DEBUG_VERBOSE, "%s",
               "Report bugs to <hamlib-developer@lists.sourceforge.net>\n\n");
 
@@ -472,7 +486,7 @@ int main(int argc, char *argv[])
 
     if (rig_file)
     {
-        strncpy(my_rig->state.rigport.pathname, rig_file, FILPATHLEN - 1);
+        strncpy(my_rig->state.rigport.pathname, rig_file, HAMLIB_FILPATHLEN - 1);
     }
 
     /*
@@ -490,12 +504,12 @@ int main(int argc, char *argv[])
 
     if (ptt_file)
     {
-        strncpy(my_rig->state.pttport.pathname, ptt_file, FILPATHLEN - 1);
+        strncpy(my_rig->state.pttport.pathname, ptt_file, HAMLIB_FILPATHLEN - 1);
     }
 
     if (dcd_file)
     {
-        strncpy(my_rig->state.dcdport.pathname, dcd_file, FILPATHLEN - 1);
+        strncpy(my_rig->state.dcdport.pathname, dcd_file, HAMLIB_FILPATHLEN - 1);
     }
 
     /* FIXME: bound checking and port type == serial */
@@ -523,6 +537,23 @@ int main(int argc, char *argv[])
      */
     if (dump_caps_opt)
     {
+
+        // if rigctld then we need to open to get the rig caps
+        if (my_model == RIG_MODEL_NETRIGCTL)
+        {
+            int ret;
+            rig_set_debug(verbose);
+            my_rig = rig_init(my_model);
+
+            if ((ret = rig_open(my_rig)) != RIG_OK)
+            {
+                fprintf(stderr, "Unable to open rigctld: %s\n", rigerror(ret));
+                exit(1);
+            }
+
+            rig_close(my_rig);
+        }
+
         dumpcaps(my_rig, stdout);
         rig_cleanup(my_rig);    /* if you care about memory */
         exit(0);
@@ -532,7 +563,8 @@ int main(int argc, char *argv[])
 
     if (retcode != RIG_OK)
     {
-        fprintf(stderr, "rig_open: error = %s \n", rigerror(retcode));
+        fprintf(stderr, "rig_open: error = %s %s %s \n", rigerror(retcode), rig_file,
+                strerror(errno));
 
         if (!ignore_rig_open_error) { exit(2); }
     }
@@ -604,19 +636,41 @@ int main(int argc, char *argv[])
     }
 
 #endif  /* HAVE_LIBREADLINE */
+    int rig_opened = 1;  // our rig is already open
 
     do
     {
+        if (!rig_opened)
+        {
+            // rig may have closed on us to try once to reopen
+            retcode = rig_open(my_rig);
+            rig_debug(RIG_DEBUG_WARN, "%s: rig_open again retcode=%d\n", __func__, retcode);
+        }
+
         retcode = rigctl_parse(my_rig, stdin, stdout, argv, argc, NULL,
                                interactive, prompt, &vfo_opt, send_cmd_term,
                                &ext_resp, &resp_sep);
 
-        if (retcode == 2)
+        // if we get a hard error we try to reopen the rig again
+        // this should cover short dropouts that can occur
+        if (retcode < 0 && !RIG_IS_SOFT_ERRCODE(-retcode))
         {
-            exitcode = 2;
+            int retry = 3;
+            rig_debug(RIG_DEBUG_ERR, "%s: i/o error\n", __func__)
+
+            do
+            {
+                retcode = rig_close(my_rig);
+                hl_usleep(1000 * 1000);
+                rig_debug(RIG_DEBUG_ERR, "%s: rig_close retcode=%d\n", __func__, retcode);
+                retcode = rig_open(my_rig);
+                rig_opened = retcode == RIG_OK ? 1 : 0;
+                rig_debug(RIG_DEBUG_ERR, "%s: rig_open retcode=%d\n", __func__, retcode);
+            }
+            while (retry-- > 0 && retcode != RIG_OK);
         }
     }
-    while (retcode == 0 || retcode == 2 || retcode == -RIG_ENAVAIL);
+    while (retcode == RIG_OK || RIG_IS_SOFT_ERRCODE(-retcode));
 
     if (interactive && prompt)
     {
@@ -675,10 +729,11 @@ void usage(void)
         "  -I, --save-history            save current interactive session history\n"
 #endif
         "  -v, --verbose                 set verbose mode, cumulative (-v to -vvvvv)\n"
-        "  -Y, --ignore_err              ignore rig_open errors\n"
+        "  -Y, --ignore-err              ignore rig_open errors\n"
         "  -Z, --debug-time-stamps       enable time stamps for debug messages\n"
         "  -h, --help                    display this help and exit\n"
-        "  -V, --version                 output version information and exit\n\n"
+        "  -V, --version                 output version information and exit\n"
+        "  -!, --cookie                  use cookie control\n\n"
     );
 
     usage_rig(stdout);
