@@ -221,7 +221,7 @@ int main(int argc, char *argv[])
     char conf_parms[MAXCONFLEN] = "";
     int status;
 
-    printf("rigctlcom Version 1.1\n");
+    printf("rigctlcom Version 1.2\n");
 
     while (1)
     {
@@ -464,7 +464,7 @@ int main(int argc, char *argv[])
 
     rig_set_debug(verbose);
 
-    rig_debug(RIG_DEBUG_VERBOSE, "%s, %s\n", "rigctlcom", hamlib_version);
+    rig_debug(RIG_DEBUG_VERBOSE, "%s, %s\n", "rigctlcom", hamlib_version2);
     rig_debug(RIG_DEBUG_VERBOSE, "%s",
               "Report bugs to <hamlib-developer@lists.sourceforge.net>\n\n");
 
@@ -502,7 +502,7 @@ int main(int argc, char *argv[])
 
     if (rig_file)
     {
-        strncpy(my_rig->state.rigport.pathname, rig_file, FILPATHLEN - 1);
+        strncpy(my_rig->state.rigport.pathname, rig_file, HAMLIB_FILPATHLEN - 1);
     }
 
     if (!rig_file2)
@@ -511,7 +511,7 @@ int main(int argc, char *argv[])
         exit(2);
     }
 
-    strncpy(my_com.pathname, rig_file2, FILPATHLEN - 1);
+    strncpy(my_com.pathname, rig_file2, HAMLIB_FILPATHLEN - 1);
 
     /*
      * ex: RIG_PTT_PARALLEL and /dev/parport0
@@ -528,12 +528,12 @@ int main(int argc, char *argv[])
 
     if (ptt_file)
     {
-        strncpy(my_rig->state.pttport.pathname, ptt_file, FILPATHLEN - 1);
+        strncpy(my_rig->state.pttport.pathname, ptt_file, HAMLIB_FILPATHLEN - 1);
     }
 
     if (dcd_file)
     {
-        strncpy(my_rig->state.dcdport.pathname, dcd_file, FILPATHLEN - 1);
+        strncpy(my_rig->state.dcdport.pathname, dcd_file, HAMLIB_FILPATHLEN - 1);
     }
 
     /* FIXME: bound checking and port type == serial */
@@ -653,7 +653,8 @@ static rmode_t ts2000_get_mode()
 {
     rmode_t mode;
     pbwidth_t width;
-    rig_get_mode(my_rig, vfo_fixup(my_rig, RIG_VFO_A), &mode, &width);
+    rig_get_mode(my_rig, vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split),
+                 &mode, &width);
 
     // Perhaps we should emulate a rig that has PKT modes instead??
     switch (mode)
@@ -740,7 +741,8 @@ static int handle_ts2000(void *arg)
         int p13 = 0;            // P13 Tone dummy value for now
         int p14 = 0;            // P14 Tone Freq dummy value for now
         int p15 = 0;            // P15 Shift status dummy value for now
-        int retval = rig_get_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_A), &freq);
+        int retval = rig_get_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
+                                  my_rig->state.cache.split), &freq);
         char response[64];
         char *fmt =
             // cppcheck-suppress *
@@ -752,7 +754,8 @@ static int handle_ts2000(void *arg)
         }
 
         mode = ts2000_get_mode();
-        retval = rig_get_ptt(my_rig, vfo_fixup(my_rig, RIG_VFO_A), &ptt);
+        retval = rig_get_ptt(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
+                                               my_rig->state.cache.split), &ptt);
 
         if (retval != RIG_OK)
         {
@@ -834,7 +837,8 @@ static int handle_ts2000(void *arg)
         freq_t freq = 0;
         char response[32];
 
-        int retval = rig_get_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_A), &freq);
+        int retval = rig_get_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
+                                  my_rig->state.cache.split), &freq);
 
         if (retval != RIG_OK)
         {
@@ -850,7 +854,8 @@ static int handle_ts2000(void *arg)
     {
         char response[32];
         freq_t freq = 0;
-        int retval = rig_get_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_B), &freq);
+        int retval = rig_get_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_B,
+                                  my_rig->state.cache.split), &freq);
 
         if (retval != RIG_OK)
         {
@@ -873,13 +878,39 @@ static int handle_ts2000(void *arg)
     {
         char response[32];
 
+        rig_set_ptt(my_rig, vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split), 0);
         snprintf(response, sizeof(response), "RX0;");
         return write_block2((void *)__func__, &my_com, response, strlen(response));
     }
     // Now some commands to set things
+    else if (strncmp(arg, "SA", 2) == 0)
+    {
+        if (strcmp(arg, "SA;") == 0)
+        {
+            // should we silently fail with RIG_OK instead? TBD
+            RETURNFUNC(-RIG_ENIMPL);
+        }
+
+        if (strlen(arg) > 3 && ((char *)arg)[2] == '1')
+        {
+            if (my_rig->caps->has_set_func)
+            {
+                int retval = rig_set_func(my_rig, RIG_VFO_CURR, RIG_FUNC_SATMODE,
+                                          ((char *)arg)[2] == '1' ? 1 : 0);
+                return retval;
+            }
+            else
+            {
+                RETURNFUNC(-RIG_ENAVAIL);
+            }
+        }
+
+        return RIG_OK;
+    }
     else if (strcmp(arg, "TX;") == 0)
     {
-        return rig_set_ptt(my_rig, vfo_fixup(my_rig, RIG_VFO_A), 1);
+        return rig_set_ptt(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
+                                             my_rig->state.cache.split), 1);
     }
     else if (strcmp(arg, "AI0;") == 0)
     {
@@ -893,11 +924,13 @@ static int handle_ts2000(void *arg)
     }
     else if (strcmp(arg, "FR0;") == 0)
     {
-        return rig_set_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_A));
+        return rig_set_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
+                                             my_rig->state.cache.split));
     }
     else if (strcmp(arg, "FR1;") == 0)
     {
-        return rig_set_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_B));
+        return rig_set_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_B,
+                                             my_rig->state.cache.split));
     }
     else if (strcmp(arg, "FR;") == 0)
     {
@@ -914,8 +947,8 @@ static int handle_ts2000(void *arg)
         }
 
 
-        if (vfo == vfo_fixup(my_rig, RIG_VFO_A)) { nvfo = 0; }
-        else if (vfo == vfo_fixup(my_rig, RIG_VFO_B)) { nvfo = 1; }
+        if (vfo == vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split)) { nvfo = 0; }
+        else if (vfo == vfo_fixup(my_rig, RIG_VFO_B, my_rig->state.cache.split)) { nvfo = 1; }
         else
         {
             retval = -RIG_EPROTO;
@@ -930,7 +963,7 @@ static int handle_ts2000(void *arg)
     else if (strcmp(arg, "FT;") == 0)
     {
         char response[32];
-        vfo_t vfo, vfo_curr = vfo_fixup(my_rig, RIG_VFO_A);
+        vfo_t vfo, vfo_curr = vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split);
         split_t split;
         int nvfo = 0;
         int retval = rig_get_split_vfo(my_rig, vfo_curr, &split, &vfo);
@@ -943,8 +976,8 @@ static int handle_ts2000(void *arg)
         }
 
 
-        if (vfo == vfo_fixup(my_rig, RIG_VFO_A)) { nvfo = 0; }
-        else if (vfo == vfo_fixup(my_rig, RIG_VFO_B)) { nvfo = 1; }
+        if (vfo == vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split)) { nvfo = 0; }
+        else if (vfo == vfo_fixup(my_rig, RIG_VFO_B, my_rig->state.cache.split)) { nvfo = 1; }
         else
         {
             retval = -RIG_EPROTO;
@@ -993,7 +1026,8 @@ static int handle_ts2000(void *arg)
     {
         char response[32];
         int valA;
-        int retval = rig_get_func(my_rig, vfo_fixup(my_rig, RIG_VFO_A), RIG_FUNC_AIP,
+        int retval = rig_get_func(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
+                                  my_rig->state.cache.split), RIG_FUNC_AIP,
                                   &valA);
         int valB;
 
@@ -1012,7 +1046,8 @@ static int handle_ts2000(void *arg)
             return retval;
         }
 
-        retval = rig_get_func(my_rig, vfo_fixup(my_rig, RIG_VFO_B), RIG_FUNC_AIP,
+        retval = rig_get_func(my_rig, vfo_fixup(my_rig, RIG_VFO_B,
+                                                my_rig->state.cache.split), RIG_FUNC_AIP,
                               &valB);
 
         if (retval != RIG_OK)
@@ -1038,7 +1073,8 @@ static int handle_ts2000(void *arg)
                       (char *)arg);
         }
 
-        retval = rig_set_func(my_rig, vfo_fixup(my_rig, RIG_VFO_A), RIG_FUNC_AIP, valA);
+        retval = rig_set_func(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
+                                                my_rig->state.cache.split), RIG_FUNC_AIP, valA);
 
         if (retval != RIG_OK)
         {
@@ -1047,7 +1083,8 @@ static int handle_ts2000(void *arg)
             return retval;
         }
 
-        retval = rig_set_func(my_rig, vfo_fixup(my_rig, RIG_VFO_B), RIG_FUNC_AIP, valB);
+        retval = rig_set_func(my_rig, vfo_fixup(my_rig, RIG_VFO_B,
+                                                my_rig->state.cache.split), RIG_FUNC_AIP, valB);
 
         if (retval != RIG_OK)
         {
@@ -1412,7 +1449,7 @@ static int handle_ts2000(void *arg)
     }
     else if (strcmp(arg, "DC;") == 0)
     {
-        vfo_t vfo, vfo_curr = vfo_fixup(my_rig, RIG_VFO_A);
+        vfo_t vfo, vfo_curr = vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split);
         split_t split;
         char response[32];
         int retval = rig_get_split_vfo(my_rig, vfo_curr, &split, &vfo);
@@ -1431,7 +1468,7 @@ static int handle_ts2000(void *arg)
     }
     else if (strncmp(arg, "DC", 2) == 0)
     {
-        vfo_t vfo_curr = vfo_fixup(my_rig, RIG_VFO_A);
+        vfo_t vfo_curr = vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split);
         split_t split;
         int isplit;
         int retval;
@@ -1462,27 +1499,31 @@ static int handle_ts2000(void *arg)
     }
     else if (strcmp(arg, "FT0;") == 0)
     {
-        return rig_set_split_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_A), vfo_fixup(my_rig,
-                                 RIG_VFO_A), 0);
+        return rig_set_split_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
+                                 my_rig->state.cache.split), vfo_fixup(my_rig,
+                                         RIG_VFO_A, my_rig->state.cache.split), 0);
     }
     else if (strcmp(arg, "FT1;") == 0)
     {
-        return rig_set_split_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_B), vfo_fixup(my_rig,
-                                 RIG_VFO_B), 0);
+        return rig_set_split_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_B,
+                                 my_rig->state.cache.split), vfo_fixup(my_rig,
+                                         RIG_VFO_B, my_rig->state.cache.split), 0);
     }
     else if (strncmp(arg, "FA0", 3) == 0)
     {
         freq_t freq;
 
         sscanf((char *)arg + 2, "%"SCNfreq, &freq);
-        return rig_set_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_A), freq);
+        return rig_set_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
+                                              my_rig->state.cache.split), freq);
     }
     else if (strncmp(arg, "FB0", 3) == 0)
     {
         freq_t freq;
 
         sscanf((char *)arg + 2, "%"SCNfreq, &freq);
-        return rig_set_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_A), freq);
+        return rig_set_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_B,
+                                              my_rig->state.cache.split), freq);
     }
     else if (strncmp(arg, "MD", 2) == 0)
     {
