@@ -76,6 +76,7 @@
 #include "iofunc.h"
 #include "serial.h"
 #include "sprintflst.h"
+#include "network.h"
 
 #include "rigctl_parse.h"
 
@@ -83,10 +84,9 @@
 /*
  * Reminder: when adding long options,
  *      keep up to date SHORT_OPTIONS, usage()'s output and man page. thanks.
- * NB: do NOT use -W since it's reserved by POSIX.
  * TODO: add an option to read from a file
  */
-#define SHORT_OPTIONS "m:r:p:d:P:D:s:c:T:t:C:W:x:z:lLuovhVZ"
+#define SHORT_OPTIONS "m:r:p:d:P:D:s:c:T:t:C:W:x:z:lLuovhVZM"
 static struct option long_options[] =
 {
     {"model",           1, 0, 'm'},
@@ -110,6 +110,7 @@ static struct option long_options[] =
     {"twiddle_timeout", 1, 0, 'W'},
     {"uplink",          1, 0, 'x'},
     {"debug-time-stamps", 0, 0, 'Z'},
+    {"multicast-addr",  1, 0, 'M'},
     {0, 0, 0, 0}
 };
 
@@ -143,10 +144,13 @@ static int volatile ctrl_c;
 
 const char *portno = "4532";
 const char *src_addr = NULL; /* INADDR_ANY */
+const char *multicast_addr = "0.0.0.0";
 
 #define MAXCONFLEN 1024
 
-static void sync_callback(int lock)
+extern void sync_callback(int lock);
+#if 0
+void sync_callback(int lock)
 {
 #ifdef HAVE_PTHREAD
     static pthread_mutex_t client_lock = PTHREAD_MUTEX_INITIALIZER;
@@ -164,6 +168,7 @@ static void sync_callback(int lock)
 
 #endif
 }
+#endif
 
 #ifdef WIN32
 static BOOL WINAPI CtrlHandler(DWORD fdwCtrlType)
@@ -248,10 +253,11 @@ int main(int argc, char *argv[])
     struct addrinfo hints, *result, *saved_result;
     int sock_listen;
     int reuseaddr = 1;
-    int twiddle = 0;
+    int twiddle_timeout = 0;
     int uplink = 0;
     char host[NI_MAXHOST];
     char serv[NI_MAXSERV];
+    char rigstartup[1024];
 #if HAVE_SIGACTION
     struct sigaction act;
 #endif
@@ -262,6 +268,7 @@ int main(int argc, char *argv[])
 #endif
     struct handle_data *arg;
     int vfo_mode = 0; /* vfo_mode=0 means target VFO is current VFO */
+    int i;
 
     while (1)
     {
@@ -287,7 +294,7 @@ int main(int argc, char *argv[])
             exit(0);
 
         case 'V':
-            version();
+            printf("rigctl %s\n", hamlib_version2);
             exit(0);
 
         case 'm':
@@ -497,7 +504,7 @@ int main(int argc, char *argv[])
 
         case 'o':
             vfo_mode++;
-            rig_debug(RIG_DEBUG_ERR, "%s: #0 vfo_mode=%d\n", __func__, vfo_mode);
+            //rig_debug(RIG_DEBUG_ERR, "%s: #0 vfo_mode=%d\n", __func__, vfo_mode);
             break;
 
         case 'v':
@@ -523,7 +530,9 @@ int main(int argc, char *argv[])
                 exit(1);
             }
 
-            twiddle = atoi(optarg);
+            twiddle_timeout = atoi(optarg);
+            fprintf(stderr,
+                    "twiddle_timeout is deprecated...use e.g. --set-conf=twiddle_timeout=5\n");
             break;
 
         case 'x':
@@ -541,22 +550,41 @@ int main(int argc, char *argv[])
             rig_set_debug_time_stamp(1);
             break;
 
+        case 'M':
+            if (!optarg)
+            {
+                usage();    /* wrong arg count */
+                exit(1);
+            }
+
+            multicast_addr = optarg;
+            break;
+
         default:
             usage();    /* unknown option? */
             exit(1);
         }
     }
 
+#if 0
+
     if (!vfo_mode)
     {
         printf("Recommend using --vfo switch for rigctld if client supports it\n");
         printf("rigctl and netrigctl will automatically detect vfo mode\n");
     }
 
+#endif
+
     rig_set_debug(verbose);
 
-    rig_debug(RIG_DEBUG_VERBOSE, "rigctld %s\nLast commit was %s\n", hamlib_version,
-              HAMLIBDATETIME);
+    snprintf(rigstartup, sizeof(rigstartup), "%s(%d) Startup:", __FILE__, __LINE__);
+
+    for (i = 0; i < argc; ++i) { strcat(rigstartup, " "); strcat(rigstartup, argv[i]); }
+
+    rig_debug(RIG_DEBUG_VERBOSE, "%s\n", rigstartup);
+
+    rig_debug(RIG_DEBUG_VERBOSE, "rigctld %s\n", hamlib_version2);
     rig_debug(RIG_DEBUG_VERBOSE, "%s",
               "Report bugs to <hamlib-developer@lists.sourceforge.net>\n\n");
 
@@ -582,13 +610,14 @@ int main(int argc, char *argv[])
 
     if (rig_file)
     {
-        strncpy(my_rig->state.rigport.pathname, rig_file, FILPATHLEN - 1);
+        strncpy(my_rig->state.rigport.pathname, rig_file, HAMLIB_FILPATHLEN - 1);
     }
 
-    my_rig->state.twiddle_timeout = twiddle;
+    my_rig->state.twiddle_timeout = twiddle_timeout;
     my_rig->state.uplink = uplink;
-    rig_debug(RIG_DEBUG_TRACE, "%s: twiddle=%d, uplink=%d\n", __func__,
-              my_rig->state.twiddle_timeout, my_rig->state.uplink);
+    rig_debug(RIG_DEBUG_TRACE, "%s: twiddle=%d, uplink=%d, twiddle_rit=%d\n",
+              __func__,
+              my_rig->state.twiddle_timeout, my_rig->state.uplink, my_rig->state.twiddle_rit);
 
     /*
      * ex: RIG_PTT_PARALLEL and /dev/parport0
@@ -605,12 +634,12 @@ int main(int argc, char *argv[])
 
     if (ptt_file)
     {
-        strncpy(my_rig->state.pttport.pathname, ptt_file, FILPATHLEN - 1);
+        strncpy(my_rig->state.pttport.pathname, ptt_file, HAMLIB_FILPATHLEN - 1);
     }
 
     if (dcd_file)
     {
-        strncpy(my_rig->state.dcdport.pathname, dcd_file, FILPATHLEN - 1);
+        strncpy(my_rig->state.dcdport.pathname, dcd_file, HAMLIB_FILPATHLEN - 1);
     }
 
     /* FIXME: bound checking and port type == serial */
@@ -648,7 +677,8 @@ int main(int argc, char *argv[])
 
     if (retcode != RIG_OK)
     {
-        fprintf(stderr, "rig_open: error = %s \n", rigerror(retcode));
+        fprintf(stderr, "rig_open: error = %s %s %s \n", rigerror(retcode), rig_file,
+                strerror(errno));
         exit(2);
     }
 
@@ -728,6 +758,17 @@ int main(int argc, char *argv[])
 
     saved_result = result;
 
+    enum multicast_item_e items = RIG_MULTICAST_POLL | RIG_MULTICAST_TRANSCEIVE |
+                                  RIG_MULTICAST_SPECTRUM;
+    retcode = network_multicast_server(my_rig, multicast_addr, 4532, items);
+
+    if (retcode != RIG_OK)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: network_multicast_server failed: %s\n", __FILE__,
+                  rigerror(retcode));
+        // we will consider this non-fatal for now
+    }
+
     do
     {
         sock_listen = socket(result->ai_family,
@@ -882,11 +923,21 @@ int main(int argc, char *argv[])
         timeout.tv_usec = 0;
         retcode = select(sock_listen + 1, &set, NULL, NULL, &timeout);
 
-        if (-1 == retcode)
+        if (retcode == -1)
         {
-            rig_debug(RIG_DEBUG_ERR, "%s: select\n", __func__);
+            int errno_stored = errno;
+            rig_debug(RIG_DEBUG_ERR, "%s: select() failed: %s\n", __func__,
+                      strerror(errno_stored));
+
+            // TODO: FIXME: Why does this select() return EINTR after any command when set_trn RIG is enabled?
+            if (errno == EINTR)
+            {
+                rig_debug(RIG_DEBUG_VERBOSE, "%s: ignoring interrupted system call\n",
+                          __func__);
+                retcode = 0;
+            }
         }
-        else if (!retcode)
+        else if (retcode == 0)
         {
             if (ctrl_c)
             {
@@ -969,6 +1020,32 @@ int main(int argc, char *argv[])
     return 0;
 }
 
+static FILE *get_fsockout(struct handle_data *handle_data_arg)
+{
+#ifdef __MINGW32__
+    int sock_osfhandle = _open_osfhandle(handle_data_arg->sock, _O_RDONLY);
+    return _fdopen(sock_osfhandle, "wb");
+#else
+    return fdopen(handle_data_arg->sock, "wb");
+#endif
+}
+
+static FILE *get_fsockin(struct handle_data *handle_data_arg)
+{
+#ifdef __MINGW32__
+    int sock_osfhandle = _open_osfhandle(handle_data_arg->sock, _O_RDONLY);
+
+    if (sock_osfhandle == -1)
+    {
+        rig_debug(RIG_DEBUG_ERR, "_open_osfhandle error: %s\n", strerror(errno));
+        return NULL;
+    }
+
+    return _fdopen(sock_osfhandle,  "rb");
+#else
+    return fdopen(handle_data_arg->sock, "rb");
+#endif
+}
 
 /*
  * This is the function run by the threads
@@ -985,36 +1062,23 @@ void *handle_socket(void *arg)
     int ext_resp = 0;
     char resp_sep = '\n';
 
-#ifdef __MINGW32__
-    int sock_osfhandle = _open_osfhandle(handle_data_arg->sock, _O_RDONLY);
+    ENTERFUNC;
 
-    if (sock_osfhandle == -1)
-    {
-        rig_debug(RIG_DEBUG_ERR, "_open_osfhandle error: %s\n", strerror(errno));
-        goto handle_exit;
-    }
-
-    fsockin = _fdopen(sock_osfhandle,  "rb");
-#else
-    fsockin = fdopen(handle_data_arg->sock, "rb");
-#endif
+    fsockin = get_fsockin(handle_data_arg);
 
     if (!fsockin)
     {
-        rig_debug(RIG_DEBUG_ERR, "fdopen(0x%d) in: %s\n", handle_data_arg->sock,
+        rig_debug(RIG_DEBUG_ERR, "%s: fdopen(0x%d) in: %s\n", __func__,
+                  handle_data_arg->sock,
                   strerror(errno));
         goto handle_exit;
     }
 
-#ifdef __MINGW32__
-    fsockout = _fdopen(sock_osfhandle, "wb");
-#else
-    fsockout = fdopen(handle_data_arg->sock, "wb");
-#endif
+    fsockout = get_fsockout(handle_data_arg);
 
     if (!fsockout)
     {
-        rig_debug(RIG_DEBUG_ERR, "fdopen out: %s\n", strerror(errno));
+        rig_debug(RIG_DEBUG_ERR, "%s: fdopen out: %s\n", __func__, strerror(errno));
         fclose(fsockin);
 
         goto handle_exit;
@@ -1053,35 +1117,54 @@ void *handle_socket(void *arg)
 
 #endif
 
+    int rig_opened = 1;  // our rig is already open
+
     do
     {
-        rig_debug(RIG_DEBUG_TRACE, "%s: vfo_mode=%d\n", __func__,
-                  handle_data_arg->vfo_mode);
-        retcode = rigctl_parse(handle_data_arg->rig, fsockin, fsockout, NULL, 0,
-                               sync_callback,
-                               1, 0, &handle_data_arg->vfo_mode, send_cmd_term, &ext_resp, &resp_sep);
-
-        if (retcode != 0) { rig_debug(RIG_DEBUG_ERR, "%s: rigctl_parse retcode=%d\n", __func__, retcode); }
-
-        if (retcode == -1)
+        if (!rig_opened)
         {
-            //sleep(1); // probably don't need this delay
-            continue;
+            retcode = rig_open(my_rig);
+            rig_opened = retcode == RIG_OK ? 1 : 0;
+            rig_debug(RIG_DEBUG_ERR, "%s: rig_open reopened retcode=%d\n", __func__,
+                      retcode);
         }
 
-        if (ferror(fsockin) || ferror(fsockout))
+        if (rig_opened) // only do this if rig is open
         {
-            rig_debug(RIG_DEBUG_ERR, "%s: socket error in=%d, out=%d\n", __func__,
-                      ferror(fsockin), ferror(fsockout));
+            rig_debug(RIG_DEBUG_TRACE, "%s: doing rigctl_parse vfo_mode=%d\n", __func__,
+                      handle_data_arg->vfo_mode);
+            retcode = rigctl_parse(handle_data_arg->rig, fsockin, fsockout, NULL, 0,
+                                   sync_callback,
+                                   1, 0, &handle_data_arg->vfo_mode, send_cmd_term, &ext_resp, &resp_sep);
 
-            retcode = rig_close(my_rig);
-            rig_debug(RIG_DEBUG_ERR, "%s: rig_close retcode=%d\n", __func__, retcode);
-            retcode = rig_open(my_rig);
-            rig_debug(RIG_DEBUG_ERR, "%s: rig_open retcode=%d\n", __func__, retcode);
+            if (retcode != 0) { rig_debug(RIG_DEBUG_VERBOSE, "%s: rigctl_parse retcode=%d\n", __func__, retcode); }
+        }
+        else
+        {
+            retcode = -RIG_EIO;
+        }
+
+        // if we get a hard error we try to reopen the rig again
+        // this should cover short dropouts that can occur
+        if (retcode < 0 && !RIG_IS_SOFT_ERRCODE(-retcode))
+        {
+            int retry = 3;
+            rig_debug(RIG_DEBUG_ERR, "%s: i/o error\n", __func__)
+
+            do
+            {
+                retcode = rig_close(my_rig);
+                hl_usleep(1000 * 1000);
+                rig_debug(RIG_DEBUG_ERR, "%s: rig_close retcode=%d\n", __func__, retcode);
+                retcode = rig_open(my_rig);
+                rig_opened = retcode == RIG_OK ? 1 : 0;
+                rig_debug(RIG_DEBUG_ERR, "%s: rig_open retcode=%d, opened=%d\n", __func__,
+                          retcode, rig_opened);
+            }
+            while (retry-- > 0 && retcode != RIG_OK);
         }
     }
-
-    while (retcode == 0 || retcode == 2 || retcode == -RIG_ENAVAIL);
+    while (retcode == RIG_OK || RIG_IS_SOFT_ERRCODE(-retcode));
 
 #ifdef HAVE_PTHREAD
 #if 0
@@ -1141,8 +1224,10 @@ handle_exit:
     if (retcode != 0) { rig_debug(RIG_DEBUG_ERR, "%s: fclose(fsockin) %s\n", __func__, strerror(retcode)); }
 
 #endif
-    fclose(fsockin);
-    fclose(fsockout);
+
+    if (fsockin) { fclose(fsockin); }
+
+    if (fsockout) { fclose(fsockout); }
 
 // for everybody else we close the handle after fclose
 #ifndef __MINGW32__
@@ -1185,8 +1270,10 @@ void usage(void)
         "  -o, --vfo                     do not default to VFO_CURR, require extra vfo arg\n"
         "  -v, --verbose                 set verbose mode, cumulative (-v to -vvvvv)\n"
         "  -W, --twiddle_timeout         timeout after detecting vfo manual change\n"
+        "  -W, --twiddle_rit             suppress VFOB getfreq so RIT can be twiddled\n"
         "  -x, --uplink                  set uplink get_freq ignore, 1=Sub, 2=Main\n"
         "  -Z, --debug-time-stamps       enable time stamps for debug messages\n"
+        "  -M, --multicast-addr=addr     set multicast addr, default 0.0.0.0 (off), recommend 224.0.1.1\n"
         "  -h, --help                    display this help and exit\n"
         "  -V, --version                 output version information and exit\n\n",
         portno);
